body {
  margin: 0;
 --general-font-family: 'Ubuntu', Roboto, -apple-system, BlinkMacSystemFont, "Segoe UI", Helvetica, Arial, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", AppleSDGothic, "Apple SD Gothic Neo", NanumGothic, "NanumGothicOTF", "Nanum Gothic", "Malgun Gothic", sans-serif;
  font-family: var(--general-font-family);
  --lumo-font-family: var(--general-font-family);
  --lumo-primary-text-color: #27824F;
  --lumo-primary-color-50pct: #27824F;
  background-color: rgba(247, 247, 246, 1);
  background-image: url("images/loading-background-large.jpg");
  background-repeat: no-repeat;
  background-attachment: fixed;
  background-position: top left;
}

.splash {
  position: absolute;
  top: calc(50% - 150px);
  left: calc(50% - 170px);
  width: 340px;
  height: 300px;
  border: 1px solid #aaaaaa;
  border-radius: 10px;
  background-color: #ffffff;
  box-shadow: 0px 0px 3px 3px rgba(0, 0, 0, 0.2);
}

.splash-header {
  width: 340px;
  height: 120px;
  background-size: contain;
  background-repeat: no-repeat;
  background-position: left top;
  background-color: RGB(246, 253, 247);
  border-top-left-radius: 10px;
  border-top-right-radius: 10px;
  font-size: 28px;
  font-weight: 400;
  line-height: 60px;
}

ul {
  list-style-type: none;
}

.splash-information .detail {
  font-weight: 400;
  font-size: 13px;
}

.loading-message {
  position: absolute;
  top: calc(50% + 108px);
  left: calc(50% - 165px);
  width: 300px;
  text-align: center;
  font-size: 16px;
}

.sk-folding-cube {
  margin: 20px auto;
  width: 15px;
  height: 15px;
  position: absolute;
  top: calc(50% + 110px);
  left: calc(50% - 130px);
  margin: auto;
  -webkit-transform: rotateZ(45deg);
  transform: rotateZ(45deg);
}

.sk-folding-cube .sk-cube {
  float: left;
  width: 50%;
  height: 50%;
  position: relative;
  -webkit-transform: scale(1.1);
  -ms-transform: scale(1.1);
  transform: scale(1.1);
}

.sk-folding-cube .sk-cube:before {
  content: '';
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: #3e872d;
  -webkit-animation: sk-foldCubeAngle 2.4s infinite linear both;
  animation: sk-foldCubeAngle 2.4s infinite linear both;
  -webkit-transform-origin: 100% 100%;
  -ms-transform-origin: 100% 100%;
  transform-origin: 100% 100%;
}

.sk-folding-cube .sk-cube2 {
  -webkit-transform: scale(1.1) rotateZ(90deg);
  transform: scale(1.1) rotateZ(90deg);
}

.sk-folding-cube .sk-cube3 {
  -webkit-transform: scale(1.1) rotateZ(180deg);
  transform: scale(1.1) rotateZ(180deg);
}

.sk-folding-cube .sk-cube4 {
  -webkit-transform: scale(1.1) rotateZ(270deg);
  transform: scale(1.1) rotateZ(270deg);
}

.sk-folding-cube .sk-cube2:before {
  -webkit-animation-delay: 0.3s;
  animation-delay: 0.3s;
}

.sk-folding-cube .sk-cube3:before {
  -webkit-animation-delay: 0.6s;
  animation-delay: 0.6s;
}

.sk-folding-cube .sk-cube4:before {
  -webkit-animation-delay: 0.9s;
  animation-delay: 0.9s;
}

@-webkit-keyframes sk-foldCubeAngle {
  0%,
  10% {
    -webkit-transform: perspective(140px) rotateX(-180deg);
    transform: perspective(140px) rotateX(-180deg);
    opacity: 0;
  }
  25%,
  75% {
    -webkit-transform: perspective(140px) rotateX(0deg);
    transform: perspective(140px) rotateX(0deg);
    opacity: 1;
  }
  90%,
  100% {
    -webkit-transform: perspective(140px) rotateY(180deg);
    transform: perspective(140px) rotateY(180deg);
    opacity: 0;
  }
}

@keyframes sk-foldCubeAngle {
  0%,
  10% {
    -webkit-transform: perspective(140px) rotateX(-180deg);
    transform: perspective(140px) rotateX(-180deg);
    opacity: 0;
  }
  25%,
  75% {
    -webkit-transform: perspective(140px) rotateX(0deg);
    transform: perspective(140px) rotateX(0deg);
    opacity: 1;
  }
  90%,
  100% {
    -webkit-transform: perspective(140px) rotateY(180deg);
    transform: perspective(140px) rotateY(180deg);
    opacity: 0;
  }
}

.copyright {
  font-size: 12px;
}

/* Global Vaadin components */

vaadin-combo-box-item[selected], vaadin-select-item[selected] {
    background-color: rgba(232, 247, 232, 1);
}

vaadin-combo-box-item:hover, vaadin-select-item:hover {
    background-color: rgba(247, 247, 246, 1);
}
