"use strict";(self.webpackChunkbackend_ai_webui_react=self.webpackChunkbackend_ai_webui_react||[]).push([[818],{9818:function(n,e,t){t.r(e),t.d(e,{default:function(){return x},useShadowRoot:function(){return k},useWebComponentInfo:function(){return m}});var i,o=t(9439),a=t(4519),r=t(6114),l=t(2754),c=t(7112),s=t(4447),u=t(1748),d=t(3881),g=t(9883),f=t(6670),h=t(382),b=t(2556),v=a.createContext(null),p=a.createContext(null),k=function(){return a.useContext(p)},m=function(){return a.useContext(v)},w=new c.QueryClient({defaultOptions:{queries:{suspense:!0,refetchOnWindowFocus:!1,retry:!1}}});s.ZP.use(u.Db).use(d.Z).init({backend:{loadPath:"/resources/i18n/{{lng}}.json"},lng:(null===globalThis||void 0===globalThis||null===(i=globalThis.backendaioptions)||void 0===i?void 0:i.get("current_language"))||"en",fallbackLng:"en",interpolation:{escapeValue:!1}});var x=function(n){var e=n.children,t=n.value,i=n.styles,s=n.shadowRoot,d=n.dispatchEvent,k=(0,a.useMemo)((function(){return(0,r.Df)()}),[]),m=function(){var n=(0,a.useState)(globalThis.backendaioptions.get("current_language")),e=(0,o.Z)(n,2),t=e[0],i=e[1],r=(0,u.$G)().i18n;return(0,a.useEffect)((function(){setTimeout((function(){return r.changeLanguage(t)}),0)}),[]),(0,a.useEffect)((function(){var n=function(n){var e;i(n.detail.lang);var t=(null===(e=n.detail)||void 0===e?void 0:e.lang)||"en";r.changeLanguage(t)};return window.addEventListener("langChanged",n),function(){return window.removeEventListener("langChanged",n)}}),[r]),[t]}(),x=(0,o.Z)(m,1)[0],C=(0,h.x)(),y=(0,a.useMemo)((function(){return{value:t,dispatchEvent:d}}),[t,d]);return(0,b.jsxs)(a.StrictMode,{children:[(0,b.jsxs)("style",{children:[i,"\n.anticon {\n  display: inline-block;\n  color: inherit;\n  font-style: normal;\n  line-height: 0;\n  text-align: center;\n  text-transform: none;\n  vertical-align: -0.125em;\n  text-rendering: optimizeLegibility;\n  -webkit-font-smoothing: antialiased;\n  -moz-osx-font-smoothing: grayscale;\n}\n\n.anticon > * {\n  line-height: 1;\n}\n\n.anticon svg {\n  display: inline-block;\n}\n\n.anticon::before {\n  display: none;\n}\n\n.anticon .anticon-icon {\n  display: block;\n}\n\n.anticon[tabindex] {\n  cursor: pointer;\n}\n\n.anticon-spin::before,\n.anticon-spin {\n  display: inline-block;\n  -webkit-animation: loadingCircle 1s infinite linear;\n  animation: loadingCircle 1s infinite linear;\n}\n\n@-webkit-keyframes loadingCircle {\n  100% {\n    -webkit-transform: rotate(360deg);\n    transform: rotate(360deg);\n  }\n}\n\n@keyframes loadingCircle {\n  100% {\n    -webkit-transform: rotate(360deg);\n    transform: rotate(360deg);\n  }\n}\n"]}),(0,b.jsx)(c.QueryClientProvider,{client:w,children:(0,b.jsx)(p.Provider,{value:s,children:(0,b.jsx)(v.Provider,{value:y,children:(0,b.jsx)(l.ZP,{getPopupContainer:function(n){return null!==n&&void 0!==n&&n.parentNode?n.parentNode:s},locale:"ko"===x?f.Z:g.Z,theme:C,children:(0,b.jsx)(r.V9,{container:s,cache:k,children:e})})})})})]})}}}]);
//# sourceMappingURL=818.9b28dc99.chunk.js.map