/**
@license @nocompile
Copyright (c) 2018 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
Code distributed by Google as part of the polymer project is also
subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/
(function(){/*

Copyright (c) 2016 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
Code distributed by Google as part of the polymer project is also
subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/
'use strict';var n;function aa(a){var b=0;return function(){return b<a.length?{done:!1,value:a[b++]}:{done:!0}}}function p(a){var b="undefined"!=typeof Symbol&&Symbol.iterator&&a[Symbol.iterator];return b?b.call(a):{next:aa(a)}}function r(a){if(!(a instanceof Array)){a=p(a);for(var b,c=[];!(b=a.next()).done;)c.push(b.value);a=c}return a}
function ba(a){a=["object"==typeof globalThis&&globalThis,a,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var b=0;b<a.length;++b){var c=a[b];if(c&&c.Math==Math)return c}throw Error("Cannot find global object");}var ca=ba(this);function da(){}da.prototype.toJSON=function(){return{}};function t(a){a.__shady||(a.__shady=new da);return a.__shady}function u(a){return a&&a.__shady};var w=window.ShadyDOM||{};w.Ka=!(!Element.prototype.attachShadow||!Node.prototype.getRootNode);var ea=Object.getOwnPropertyDescriptor(Node.prototype,"firstChild");w.j=!!(ea&&ea.configurable&&ea.get);w.ka=w.force||!w.Ka;w.s=w.noPatch||!1;w.R=w.preferPerformance;w.ma="on-demand"===w.s;var fa;var ha=w.querySelectorImplementation;fa=-1<["native","selectorEngine"].indexOf(ha)?ha:void 0;w.$a=fa;w.za=navigator.userAgent.match("Trident");
function ia(){return Document.prototype.msElementsFromPoint?"msElementsFromPoint":"elementsFromPoint"}function x(a){return(a=u(a))&&void 0!==a.firstChild}function y(a){return a instanceof ShadowRoot}function ja(a){return(a=(a=u(a))&&a.root)&&ka(a)}var la=Element.prototype,ma=la.matches||la.matchesSelector||la.mozMatchesSelector||la.msMatchesSelector||la.oMatchesSelector||la.webkitMatchesSelector,na=document.createTextNode(""),oa=0,pa=[];
(new MutationObserver(function(){for(;pa.length;)try{pa.shift()()}catch(a){throw na.textContent=oa++,a;}})).observe(na,{characterData:!0});function qa(a){pa.push(a);na.textContent=oa++}var ra=document.contains?function(a,b){return a.__shady_native_contains(b)}:function(a,b){return a===b||a.documentElement&&a.documentElement.__shady_native_contains(b)};function sa(a,b){for(;b;){if(b==a)return!0;b=b.__shady_parentNode}return!1}
function ta(a){for(var b=a.length-1;0<=b;b--){var c=a[b],d=c.getAttribute("id")||c.getAttribute("name");d&&"length"!==d&&isNaN(d)&&(a[d]=c)}a.item=function(e){return a[e]};a.namedItem=function(e){if("length"!==e&&isNaN(e)&&a[e])return a[e];for(var f=p(a),g=f.next();!g.done;g=f.next())if(g=g.value,(g.getAttribute("id")||g.getAttribute("name"))==e)return g;return null};return a}function ua(a){var b=[];for(a=a.__shady_native_firstChild;a;a=a.__shady_native_nextSibling)b.push(a);return b}
function va(a){var b=[];for(a=a.__shady_firstChild;a;a=a.__shady_nextSibling)b.push(a);return b}function wa(a,b,c){c.configurable=!0;if(c.value)a[b]=c.value;else try{Object.defineProperty(a,b,c)}catch(d){}}function z(a,b,c,d){c=void 0===c?"":c;for(var e in b)d&&0<=d.indexOf(e)||wa(a,c+e,b[e])}function xa(a,b){for(var c in b)c in a&&wa(a,c,b[c])}function A(a){var b={};Object.getOwnPropertyNames(a).forEach(function(c){b[c]=Object.getOwnPropertyDescriptor(a,c)});return b}
function ya(a,b){for(var c=Object.getOwnPropertyNames(b),d=0,e;d<c.length;d++)e=c[d],a[e]=b[e]}function za(a){return a instanceof Node?a:document.createTextNode(""+a)}function Aa(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];if(1===b.length)return za(b[0]);c=document.createDocumentFragment();b=p(b);for(var d=b.next();!d.done;d=b.next())c.appendChild(za(d.value));return c}
function Ba(a){var b;for(b=void 0===b?1:b;0<b;b--)a=a.reduce(function(c,d){Array.isArray(d)?c.push.apply(c,r(d)):c.push(d);return c},[]);return a}function Ca(a){var b=[],c=new Set;a=p(a);for(var d=a.next();!d.done;d=a.next())d=d.value,c.has(d)||(b.push(d),c.add(d));return b};var Da=[],Ea;function Fa(a){Ea||(Ea=!0,qa(Ga));Da.push(a)}function Ga(){Ea=!1;for(var a=!!Da.length;Da.length;)Da.shift()();return a}Ga.list=Da;function Ha(){this.g=!1;this.addedNodes=[];this.removedNodes=[];this.aa=new Set}function Ia(a){a.g||(a.g=!0,qa(function(){a.flush()}))}Ha.prototype.flush=function(){if(this.g){this.g=!1;var a=this.takeRecords();a.length&&this.aa.forEach(function(b){b(a)})}};Ha.prototype.takeRecords=function(){if(this.addedNodes.length||this.removedNodes.length){var a=[{addedNodes:this.addedNodes,removedNodes:this.removedNodes}];this.addedNodes=[];this.removedNodes=[];return a}return[]};
function Ja(a,b){var c=t(a);c.P||(c.P=new Ha);c.P.aa.add(b);var d=c.P;return{Da:b,J:d,Ea:a,takeRecords:function(){return d.takeRecords()}}}function Ka(a){var b=a&&a.J;b&&(b.aa.delete(a.Da),b.aa.size||(t(a.Ea).P=null))}
function La(a,b){var c=b.getRootNode();return a.map(function(d){var e=c===d.target.getRootNode();if(e&&d.addedNodes){if(e=[].slice.call(d.addedNodes).filter(function(f){return c===f.getRootNode()}),e.length)return d=Object.create(d),Object.defineProperty(d,"addedNodes",{value:e,configurable:!0}),d}else if(e)return d}).filter(function(d){return d})};var Ma=/[&\u00A0"]/g,Na=/[&\u00A0<>]/g;function Oa(a){switch(a){case "&":return"&amp;";case "<":return"&lt;";case ">":return"&gt;";case '"':return"&quot;";case "\u00a0":return"&nbsp;"}}function Pa(a){for(var b={},c=0;c<a.length;c++)b[a[c]]=!0;return b}var Qa=Pa("area base br col command embed hr img input keygen link meta param source track wbr".split(" ")),Ra=Pa("style script xmp iframe noembed noframes plaintext noscript".split(" "));
function Sa(a,b){"template"===a.localName&&(a=a.content);for(var c="",d=b?b(a):a.childNodes,e=0,f=d.length,g=void 0;e<f&&(g=d[e]);e++){a:{var h=g;var k=a,l=b;switch(h.nodeType){case Node.ELEMENT_NODE:k=h.localName;for(var m="<"+k,q=h.attributes,v=0,T;T=q[v];v++)m+=" "+T.name+'="'+T.value.replace(Ma,Oa)+'"';m+=">";h=Qa[k]?m:m+Sa(h,l)+"</"+k+">";break a;case Node.TEXT_NODE:h=h.data;h=k&&Ra[k.localName]?h:h.replace(Na,Oa);break a;case Node.COMMENT_NODE:h="\x3c!--"+h.data+"--\x3e";break a;default:throw window.console.error(h),
Error("not implemented");}}c+=h}return c};var Ta=w.j,Ua={querySelector:function(a){return this.__shady_native_querySelector(a)},querySelectorAll:function(a){return this.__shady_native_querySelectorAll(a)}},Va={};function Wa(a){Va[a]=function(b){return b["__shady_native_"+a]}}function Xa(a,b){z(a,b,"__shady_native_");for(var c in b)Wa(c)}function B(a,b){b=void 0===b?[]:b;for(var c=0;c<b.length;c++){var d=b[c],e=Object.getOwnPropertyDescriptor(a,d);e&&(Object.defineProperty(a,"__shady_native_"+d,e),e.value?Ua[d]||(Ua[d]=e.value):Wa(d))}}
var C=document.createTreeWalker(document,NodeFilter.SHOW_ALL,null,!1),D=document.createTreeWalker(document,NodeFilter.SHOW_ELEMENT,null,!1),Ya=document.implementation.createHTMLDocument("inert");function Za(a){for(var b;b=a.__shady_native_firstChild;)a.__shady_native_removeChild(b)}var $a=["firstElementChild","lastElementChild","children","childElementCount"],ab=["querySelector","querySelectorAll","append","prepend","replaceChildren"];
function bb(){var a=["dispatchEvent","addEventListener","removeEventListener"];window.EventTarget?(B(window.EventTarget.prototype,a),void 0===window.__shady_native_addEventListener&&B(Window.prototype,a)):(B(Node.prototype,a),B(Window.prototype,a),B(XMLHttpRequest.prototype,a));Ta?B(Node.prototype,"parentNode firstChild lastChild previousSibling nextSibling childNodes parentElement textContent".split(" ")):Xa(Node.prototype,{parentNode:{get:function(){C.currentNode=this;return C.parentNode()}},firstChild:{get:function(){C.currentNode=
this;return C.firstChild()}},lastChild:{get:function(){C.currentNode=this;return C.lastChild()}},previousSibling:{get:function(){C.currentNode=this;return C.previousSibling()}},nextSibling:{get:function(){C.currentNode=this;return C.nextSibling()}},childNodes:{get:function(){var b=[];C.currentNode=this;for(var c=C.firstChild();c;)b.push(c),c=C.nextSibling();return b}},parentElement:{get:function(){D.currentNode=this;return D.parentNode()}},textContent:{get:function(){switch(this.nodeType){case Node.ELEMENT_NODE:case Node.DOCUMENT_FRAGMENT_NODE:for(var b=
document.createTreeWalker(this,NodeFilter.SHOW_TEXT,null,!1),c="",d;d=b.nextNode();)c+=d.nodeValue;return c;default:return this.nodeValue}},set:function(b){if("undefined"===typeof b||null===b)b="";switch(this.nodeType){case Node.ELEMENT_NODE:case Node.DOCUMENT_FRAGMENT_NODE:Za(this);(0<b.length||this.nodeType===Node.ELEMENT_NODE)&&this.__shady_native_insertBefore(document.createTextNode(b),void 0);break;default:this.nodeValue=b}}}});B(Node.prototype,"appendChild insertBefore removeChild replaceChild cloneNode contains".split(" "));
B(HTMLElement.prototype,["parentElement","contains"]);a={firstElementChild:{get:function(){D.currentNode=this;return D.firstChild()}},lastElementChild:{get:function(){D.currentNode=this;return D.lastChild()}},children:{get:function(){var b=[];D.currentNode=this;for(var c=D.firstChild();c;)b.push(c),c=D.nextSibling();return ta(b)}},childElementCount:{get:function(){return this.children?this.children.length:0}}};Ta?(B(Element.prototype,$a),B(Element.prototype,["previousElementSibling","nextElementSibling",
"innerHTML","className"]),B(HTMLElement.prototype,["children","innerHTML","className"])):(Xa(Element.prototype,a),Xa(Element.prototype,{previousElementSibling:{get:function(){D.currentNode=this;return D.previousSibling()}},nextElementSibling:{get:function(){D.currentNode=this;return D.nextSibling()}},innerHTML:{get:function(){return Sa(this,ua)},set:function(b){var c="template"===this.localName?this.content:this;Za(c);var d=this.localName||"div";d=this.namespaceURI&&this.namespaceURI!==Ya.namespaceURI?
Ya.createElementNS(this.namespaceURI,d):Ya.createElement(d);d.innerHTML=b;for(b="template"===this.localName?d.content:d;d=b.__shady_native_firstChild;)c.__shady_native_insertBefore(d,void 0)}},className:{get:function(){return this.getAttribute("class")||""},set:function(b){this.setAttribute("class",b)}}}));B(Element.prototype,"setAttribute getAttribute hasAttribute removeAttribute focus blur".split(" "));B(Element.prototype,ab);B(HTMLElement.prototype,["focus","blur"]);window.HTMLTemplateElement&&
B(window.HTMLTemplateElement.prototype,["innerHTML"]);Ta?B(DocumentFragment.prototype,$a):Xa(DocumentFragment.prototype,a);B(DocumentFragment.prototype,ab);Ta?(B(Document.prototype,$a),B(Document.prototype,["activeElement"])):Xa(Document.prototype,a);B(Document.prototype,["importNode","getElementById","elementFromPoint",ia()]);B(Document.prototype,ab)};var db=A({get childNodes(){return this.__shady_childNodes},get firstChild(){return this.__shady_firstChild},get lastChild(){return this.__shady_lastChild},get childElementCount(){return this.__shady_childElementCount},get children(){return this.__shady_children},get firstElementChild(){return this.__shady_firstElementChild},get lastElementChild(){return this.__shady_lastElementChild},get shadowRoot(){return this.__shady_shadowRoot}}),eb=A({get textContent(){return this.__shady_textContent},set textContent(a){this.__shady_textContent=
a},get innerHTML(){return this.__shady_innerHTML},set innerHTML(a){this.__shady_innerHTML=a}}),fb=A({get parentElement(){return this.__shady_parentElement},get parentNode(){return this.__shady_parentNode},get nextSibling(){return this.__shady_nextSibling},get previousSibling(){return this.__shady_previousSibling},get nextElementSibling(){return this.__shady_nextElementSibling},get previousElementSibling(){return this.__shady_previousElementSibling},get className(){return this.__shady_className},set className(a){this.__shady_className=
a}});function gb(a){for(var b in a){var c=a[b];c&&(c.enumerable=!1)}}gb(db);gb(eb);gb(fb);var hb=w.j||!0===w.s,ib=hb?function(){}:function(a){var b=t(a);b.Ba||(b.Ba=!0,xa(a,fb))},jb=hb?function(){}:function(a){var b=t(a);b.Aa||(b.Aa=!0,xa(a,db),window.customElements&&window.customElements.polyfillWrapFlushCallback&&!w.s||xa(a,eb))};var kb="__eventWrappers"+Date.now(),lb=function(){var a=Object.getOwnPropertyDescriptor(Event.prototype,"composed");return a?function(b){return a.get.call(b)}:null}(),mb=function(){function a(){}var b=!1,c={get capture(){b=!0;return!1}};window.addEventListener("test",a,c);window.removeEventListener("test",a,c);return b}();function nb(a){if(null===a||"object"!==typeof a&&"function"!==typeof a){var b=!!a;var c=!1}else{b=!!a.capture;c=!!a.once;var d=a.G}return{xa:d,capture:b,once:c,wa:mb?a:b}}
var ob={blur:!0,focus:!0,focusin:!0,focusout:!0,click:!0,dblclick:!0,mousedown:!0,mouseenter:!0,mouseleave:!0,mousemove:!0,mouseout:!0,mouseover:!0,mouseup:!0,wheel:!0,beforeinput:!0,input:!0,keydown:!0,keyup:!0,compositionstart:!0,compositionupdate:!0,compositionend:!0,touchstart:!0,touchend:!0,touchmove:!0,touchcancel:!0,pointerover:!0,pointerenter:!0,pointerdown:!0,pointermove:!0,pointerup:!0,pointercancel:!0,pointerout:!0,pointerleave:!0,gotpointercapture:!0,lostpointercapture:!0,dragstart:!0,
drag:!0,dragenter:!0,dragleave:!0,dragover:!0,drop:!0,dragend:!0,DOMActivate:!0,DOMFocusIn:!0,DOMFocusOut:!0,keypress:!0},pb={DOMAttrModified:!0,DOMAttributeNameChanged:!0,DOMCharacterDataModified:!0,DOMElementNameChanged:!0,DOMNodeInserted:!0,DOMNodeInsertedIntoDocument:!0,DOMNodeRemoved:!0,DOMNodeRemovedFromDocument:!0,DOMSubtreeModified:!0};function qb(a){return a instanceof Node?a.__shady_getRootNode():a}
function rb(a,b){var c=[],d=a;for(a=qb(a);d;)c.push(d),d=d.__shady_assignedSlot?d.__shady_assignedSlot:d.nodeType===Node.DOCUMENT_FRAGMENT_NODE&&d.host&&(b||d!==a)?d.host:d.__shady_parentNode;c[c.length-1]===document&&c.push(window);return c}function sb(a){a.__composedPath||(a.__composedPath=rb(a.target,!0));return a.__composedPath}function tb(a,b){if(!y)return a;a=rb(a,!0);for(var c=0,d,e=void 0,f,g=void 0;c<b.length;c++)if(d=b[c],f=qb(d),f!==e&&(g=a.indexOf(f),e=f),!y(f)||-1<g)return d}
var ub={get composed(){void 0===this.__composed&&(lb?this.__composed="focusin"===this.type||"focusout"===this.type||lb(this):!1!==this.isTrusted&&(this.__composed=ob[this.type]));return this.__composed||!1},composedPath:function(){this.__composedPath||(this.__composedPath=rb(this.__target,this.composed));return this.__composedPath},get target(){return tb(this.currentTarget||this.__previousCurrentTarget,this.composedPath())},get relatedTarget(){if(!this.__relatedTarget)return null;this.__relatedTargetComposedPath||
(this.__relatedTargetComposedPath=rb(this.__relatedTarget,!0));return tb(this.currentTarget||this.__previousCurrentTarget,this.__relatedTargetComposedPath)},stopPropagation:function(){Event.prototype.stopPropagation.call(this);this.fa=!0},stopImmediatePropagation:function(){Event.prototype.stopImmediatePropagation.call(this);this.fa=this.__immediatePropagationStopped=!0}},vb=w.j&&Object.getOwnPropertyDescriptor(Event.prototype,"eventPhase");
vb&&(Object.defineProperty(ub,"eventPhase",{get:function(){return this.currentTarget===this.target?Event.AT_TARGET:this.__shady_native_eventPhase},enumerable:!0,configurable:!0}),Object.defineProperty(ub,"__shady_native_eventPhase",vb));function wb(a){function b(c,d){c=new a(c,d);c.__composed=d&&!!d.composed;return c}b.__proto__=a;b.prototype=a.prototype;return b}var xb={focus:!0,blur:!0};function yb(a){return a.__target!==a.target||a.__relatedTarget!==a.relatedTarget}
function zb(a,b,c){if(c=b.__handlers&&b.__handlers[a.type]&&b.__handlers[a.type][c])for(var d=0,e;(e=c[d])&&(!yb(a)||a.target!==a.relatedTarget)&&(e.call(b,a),!a.__immediatePropagationStopped);d++);}var Ab=(new Event("e")).hasOwnProperty("currentTarget");
function Bb(a){a=Ab?Object.create(a):a;var b=a.composedPath(),c=b.map(function(m){return tb(m,b)}),d=a.bubbles,e=Object.getOwnPropertyDescriptor(a,"currentTarget");Object.defineProperty(a,"currentTarget",{configurable:!0,enumerable:!0,get:function(){return k}});var f=Event.CAPTURING_PHASE,g=Object.getOwnPropertyDescriptor(a,"eventPhase");Object.defineProperty(a,"eventPhase",{configurable:!0,enumerable:!0,get:function(){return f}});try{for(var h=b.length-1;0<=h;h--){var k=b[h];f=k===c[h]?Event.AT_TARGET:
Event.CAPTURING_PHASE;zb(a,k,"capture");if(a.fa)return}for(h=0;h<b.length;h++){k=b[h];var l=k===c[h];if(l||d)if(f=l?Event.AT_TARGET:Event.BUBBLING_PHASE,zb(a,k,"bubble"),a.fa)break}}finally{Ab||(e?Object.defineProperty(a,"currentTarget",e):delete a.currentTarget,g?Object.defineProperty(a,"eventPhase",g):delete a.eventPhase)}}function Cb(a,b,c,d){for(var e=0;e<a.length;e++){var f=a[e],g=f.type,h=f.capture;if(b===f.node&&c===g&&d===h)return e}return-1}
function Db(a){Ga();return!w.R&&this instanceof Node&&!ra(document,this)?(a.__target||Eb(a,this),Bb(a)):this.__shady_native_dispatchEvent(a)}
function Fb(a,b,c){var d=this,e=nb(c),f=e.capture,g=e.once,h=e.xa;e=e.wa;if(b){var k=typeof b;if("function"===k||"object"===k)if("object"!==k||b.handleEvent&&"function"===typeof b.handleEvent){if(pb[a])return this.__shady_native_addEventListener(a,b,e);var l=h||this;if(h=b[kb]){if(-1<Cb(h,l,a,f))return}else b[kb]=[];h=function(m){g&&d.__shady_removeEventListener(a,b,c);m.__target||Eb(m);if(l!==d){var q=Object.getOwnPropertyDescriptor(m,"currentTarget");Object.defineProperty(m,"currentTarget",{get:function(){return l},
configurable:!0});var v=Object.getOwnPropertyDescriptor(m,"eventPhase");Object.defineProperty(m,"eventPhase",{configurable:!0,enumerable:!0,get:function(){return f?Event.CAPTURING_PHASE:Event.BUBBLING_PHASE}})}m.__previousCurrentTarget=m.currentTarget;if(!y(l)&&"slot"!==l.localName||-1!=m.composedPath().indexOf(l))if(m.composed||-1<m.composedPath().indexOf(l))if(yb(m)&&m.target===m.relatedTarget)m.eventPhase===Event.BUBBLING_PHASE&&m.stopImmediatePropagation();else if(m.eventPhase===Event.CAPTURING_PHASE||
m.bubbles||m.target===l||l instanceof Window){var T="function"===k?b.call(l,m):b.handleEvent&&b.handleEvent(m);l!==d&&(q?(Object.defineProperty(m,"currentTarget",q),q=null):delete m.currentTarget,v?(Object.defineProperty(m,"eventPhase",v),v=null):delete m.eventPhase);return T}};b[kb].push({node:l,type:a,capture:f,Ya:h});this.__handlers=this.__handlers||{};this.__handlers[a]=this.__handlers[a]||{capture:[],bubble:[]};this.__handlers[a][f?"capture":"bubble"].push(h);xb[a]||this.__shady_native_addEventListener(a,
h,e)}}}function Gb(a,b,c){if(b){var d=nb(c);c=d.capture;var e=d.xa;d=d.wa;if(pb[a])return this.__shady_native_removeEventListener(a,b,d);var f=e||this;e=void 0;var g=null;try{g=b[kb]}catch(h){}g&&(f=Cb(g,f,a,c),-1<f&&(e=g.splice(f,1)[0].Ya,g.length||(b[kb]=void 0)));this.__shady_native_removeEventListener(a,e||b,d);e&&this.__handlers&&this.__handlers[a]&&(a=this.__handlers[a][c?"capture":"bubble"],b=a.indexOf(e),-1<b&&a.splice(b,1))}}
function Hb(){for(var a in xb)window.__shady_native_addEventListener(a,function(b){b.__target||(Eb(b),Bb(b))},!0)}var Ib=A(ub);function Eb(a,b){b=void 0===b?a.target:b;a.__target=b;a.__relatedTarget=a.relatedTarget;if(w.j){b=Object.getPrototypeOf(a);if(!b.hasOwnProperty("__shady_patchedProto")){var c=Object.create(b);c.__shady_sourceProto=b;z(c,Ib);b.__shady_patchedProto=c}a.__proto__=b.__shady_patchedProto}else z(a,Ib)}var Jb=wb(Event),Kb=wb(CustomEvent),Lb=wb(MouseEvent);
function Mb(){if(!lb&&Object.getOwnPropertyDescriptor(Event.prototype,"isTrusted")){var a=function(){var b=new MouseEvent("click",{bubbles:!0,cancelable:!0,composed:!0});this.__shady_dispatchEvent(b)};Element.prototype.click?Element.prototype.click=a:HTMLElement.prototype.click&&(HTMLElement.prototype.click=a)}}
var Nb=Object.getOwnPropertyNames(Element.prototype).filter(function(a){return"on"===a.substring(0,2)}),Ob=Object.getOwnPropertyNames(HTMLElement.prototype).filter(function(a){return"on"===a.substring(0,2)});function Pb(a){return{set:function(b){var c=t(this),d=a.substring(2);c.F||(c.F={});c.F[a]&&this.removeEventListener(d,c.F[a]);this.__shady_addEventListener(d,b);c.F[a]=b},get:function(){var b=u(this);return b&&b.F&&b.F[a]},configurable:!0}};function Qb(a,b){return{index:a,S:[],Z:b}}
function Rb(a,b,c,d){var e=0,f=0,g=0,h=0,k=Math.min(b-e,d-f);if(0==e&&0==f)a:{for(g=0;g<k;g++)if(a[g]!==c[g])break a;g=k}if(b==a.length&&d==c.length){h=a.length;for(var l=c.length,m=0;m<k-g&&Sb(a[--h],c[--l]);)m++;h=m}e+=g;f+=g;b-=h;d-=h;if(0==b-e&&0==d-f)return[];if(e==b){for(b=Qb(e,0);f<d;)b.S.push(c[f++]);return[b]}if(f==d)return[Qb(e,b-e)];k=e;g=f;d=d-g+1;h=b-k+1;b=Array(d);for(l=0;l<d;l++)b[l]=Array(h),b[l][0]=l;for(l=0;l<h;l++)b[0][l]=l;for(l=1;l<d;l++)for(m=1;m<h;m++)if(a[k+m-1]===c[g+l-1])b[l][m]=
b[l-1][m-1];else{var q=b[l-1][m]+1,v=b[l][m-1]+1;b[l][m]=q<v?q:v}k=b.length-1;g=b[0].length-1;d=b[k][g];for(a=[];0<k||0<g;)0==k?(a.push(2),g--):0==g?(a.push(3),k--):(h=b[k-1][g-1],l=b[k-1][g],m=b[k][g-1],q=l<m?l<h?l:h:m<h?m:h,q==h?(h==d?a.push(0):(a.push(1),d=h),k--,g--):q==l?(a.push(3),k--,d=l):(a.push(2),g--,d=m));a.reverse();b=void 0;k=[];for(g=0;g<a.length;g++)switch(a[g]){case 0:b&&(k.push(b),b=void 0);e++;f++;break;case 1:b||(b=Qb(e,0));b.Z++;e++;b.S.push(c[f]);f++;break;case 2:b||(b=Qb(e,0));
b.Z++;e++;break;case 3:b||(b=Qb(e,0)),b.S.push(c[f]),f++}b&&k.push(b);return k}function Sb(a,b){return a===b};var Tb=A({dispatchEvent:Db,addEventListener:Fb,removeEventListener:Gb});var Ub=null;function E(){Ub||(Ub=window.ShadyCSS&&window.ShadyCSS.ScopingShim);return Ub||null}function Vb(a,b,c){var d=E();return d&&"class"===b?(d.setElementClass(a,c),!0):!1}function Wb(a,b){var c=E();c&&c.unscopeNode(a,b)}function Xb(a,b){var c=E();if(!c)return!0;if(a.nodeType===Node.DOCUMENT_FRAGMENT_NODE){c=!0;for(a=a.__shady_firstChild;a;a=a.__shady_nextSibling)c=c&&Xb(a,b);return c}return a.nodeType!==Node.ELEMENT_NODE?!0:c.currentScopeForNode(a)===b}
function Yb(a){if(a.nodeType!==Node.ELEMENT_NODE)return"";var b=E();return b?b.currentScopeForNode(a):""}function Zb(a,b){if(a)for(a.nodeType===Node.ELEMENT_NODE&&b(a),a=a.__shady_firstChild;a;a=a.__shady_nextSibling)a.nodeType===Node.ELEMENT_NODE&&Zb(a,b)};var $b=window.document,ac=w.R,bc=Object.getOwnPropertyDescriptor(Node.prototype,"isConnected"),cc=bc&&bc.get;function dc(a){for(var b;b=a.__shady_firstChild;)a.__shady_removeChild(b)}function ec(a){var b=u(a);if(b&&void 0!==b.ea)for(b=a.__shady_firstChild;b;b=b.__shady_nextSibling)ec(b);if(a=u(a))a.ea=void 0}function fc(a){var b=a;if(a&&"slot"===a.localName){var c=u(a);(c=c&&c.L)&&(b=c.length?c[0]:fc(a.__shady_nextSibling))}return b}
function gc(a,b,c){if(a=(a=u(a))&&a.P){if(b)if(b.nodeType===Node.DOCUMENT_FRAGMENT_NODE)for(var d=0,e=b.childNodes.length;d<e;d++)a.addedNodes.push(b.childNodes[d]);else a.addedNodes.push(b);c&&a.removedNodes.push(c);Ia(a)}}
var mc=A({get parentNode(){var a=u(this);a=a&&a.parentNode;return void 0!==a?a:this.__shady_native_parentNode},get firstChild(){var a=u(this);a=a&&a.firstChild;return void 0!==a?a:this.__shady_native_firstChild},get lastChild(){var a=u(this);a=a&&a.lastChild;return void 0!==a?a:this.__shady_native_lastChild},get nextSibling(){var a=u(this);a=a&&a.nextSibling;return void 0!==a?a:this.__shady_native_nextSibling},get previousSibling(){var a=u(this);a=a&&a.previousSibling;return void 0!==a?a:this.__shady_native_previousSibling},
get childNodes(){if(x(this)){var a=u(this);if(!a.childNodes){a.childNodes=[];for(var b=this.__shady_firstChild;b;b=b.__shady_nextSibling)a.childNodes.push(b)}var c=a.childNodes}else c=this.__shady_native_childNodes;c.item=function(d){return c[d]};return c},get parentElement(){var a=u(this);(a=a&&a.parentNode)&&a.nodeType!==Node.ELEMENT_NODE&&(a=null);return void 0!==a?a:this.__shady_native_parentElement},get isConnected(){if(cc&&cc.call(this))return!0;if(this.nodeType==Node.DOCUMENT_FRAGMENT_NODE)return!1;
var a=this.ownerDocument;if(null===a||ra(a,this))return!0;for(a=this;a&&!(a instanceof Document);)a=a.__shady_parentNode||(y(a)?a.host:void 0);return!!(a&&a instanceof Document)},get textContent(){if(x(this)){for(var a=[],b=this.__shady_firstChild;b;b=b.__shady_nextSibling)b.nodeType!==Node.COMMENT_NODE&&a.push(b.__shady_textContent);return a.join("")}return this.__shady_native_textContent},set textContent(a){if("undefined"===typeof a||null===a)a="";switch(this.nodeType){case Node.ELEMENT_NODE:case Node.DOCUMENT_FRAGMENT_NODE:if(!x(this)&&
w.j){var b=this.__shady_firstChild;(b!=this.__shady_lastChild||b&&b.nodeType!=Node.TEXT_NODE)&&dc(this);this.__shady_native_textContent=a}else dc(this),(0<a.length||this.nodeType===Node.ELEMENT_NODE)&&this.__shady_insertBefore(document.createTextNode(a));break;default:this.nodeValue=a}},insertBefore:function(a,b){if(this.ownerDocument!==$b&&a.ownerDocument!==$b)return this.__shady_native_insertBefore(a,b),a;if(a===this)throw Error("Failed to execute 'appendChild' on 'Node': The new child element contains the parent.");
if(b){var c=u(b);c=c&&c.parentNode;if(void 0!==c&&c!==this||void 0===c&&b.__shady_native_parentNode!==this)throw Error("Failed to execute 'insertBefore' on 'Node': The node before which the new node is to be inserted is not a child of this node.");}if(b===a)return a;gc(this,a);var d=[],e=(c=hc(this))?c.host.localName:Yb(this),f=a.__shady_parentNode;if(f){var g=Yb(a);var h=!!c||!hc(a)||ac&&void 0!==this.__noInsertionPoint;f.__shady_removeChild(a,h)}f=!0;var k=(!ac||void 0===a.__noInsertionPoint&&void 0===
this.__noInsertionPoint)&&!Xb(a,e),l=c&&!a.__noInsertionPoint&&(!ac||a.nodeType===Node.DOCUMENT_FRAGMENT_NODE);if(l||k)k&&(g=g||Yb(a)),Zb(a,function(m){l&&"slot"===m.localName&&d.push(m);if(k){var q=g;E()&&(q&&Wb(m,q),(q=E())&&q.scopeNode(m,e))}});d.length&&(ic(c),c.i.push.apply(c.i,r(d)),F(c));x(this)&&(jc(a,this,b),h=u(this),h.root?(f=!1,ja(this)&&F(h.root)):c&&"slot"===this.localName&&(f=!1,F(c)));f?(c=y(this)?this.host:this,b?(b=fc(b),c.__shady_native_insertBefore(a,b)):c.__shady_native_appendChild(a)):
a.ownerDocument!==this.ownerDocument&&this.ownerDocument.adoptNode(a);return a},appendChild:function(a){if(this!=a||!y(a))return this.__shady_insertBefore(a)},removeChild:function(a,b){b=void 0===b?!1:b;if(this.ownerDocument!==$b)return this.__shady_native_removeChild(a);if(a.__shady_parentNode!==this)throw Error("The node to be removed is not a child of this node: "+a);gc(this,null,a);var c=hc(a),d=c&&kc(c,a),e=u(this);if(x(this)&&(lc(a,this),ja(this))){F(e.root);var f=!0}if(E()&&!b&&c&&a.nodeType!==
Node.TEXT_NODE){var g=Yb(a);Zb(a,function(h){Wb(h,g)})}ec(a);c&&((b="slot"===this.localName)&&(f=!0),(d||b)&&F(c));f||(f=y(this)?this.host:this,(!e.root&&"slot"!==a.localName||f===a.__shady_native_parentNode)&&f.__shady_native_removeChild(a));return a},replaceChild:function(a,b){this.__shady_insertBefore(a,b);this.__shady_removeChild(b);return a},cloneNode:function(a){if("template"==this.localName)return this.__shady_native_cloneNode(a);var b=this.__shady_native_cloneNode(!1);if(a&&b.nodeType!==Node.ATTRIBUTE_NODE){a=
this.__shady_firstChild;for(var c;a;a=a.__shady_nextSibling)c=a.__shady_cloneNode(!0),b.__shady_appendChild(c)}return b},getRootNode:function(a){if(this&&this.nodeType){var b=t(this),c=b.ea;void 0===c&&(y(this)?(c=this,b.ea=c):(c=(c=this.__shady_parentNode)?c.__shady_getRootNode(a):this,document.documentElement.__shady_native_contains(this)&&(b.ea=c)));return c}},contains:function(a){return sa(this,a)}});var oc=A({get assignedSlot(){var a=this.__shady_parentNode;(a=a&&a.__shady_shadowRoot)&&nc(a);return(a=u(this))&&a.assignedSlot||null}});/*

 Copyright (c) 2022 The Polymer Project Authors
 SPDX-License-Identifier: BSD-3-Clause
*/
var pc=new Map;[["(",{end:")",da:!0}],["[",{end:"]",da:!0}],['"',{end:'"',da:!1}],["'",{end:"'",da:!1}]].forEach(function(a){var b=p(a);a=b.next().value;b=b.next().value;pc.set(a,b)});function qc(a,b,c,d){for(d=void 0===d?!0:d;b<a.length;b++)if("\\"===a[b]&&b<a.length-1&&"\n"!==a[b+1])b++;else{if(-1!==c.indexOf(a[b]))return b;if(d&&pc.has(a[b])){var e=pc.get(a[b]);b=qc(a,b+1,[e.end],e.da)}}return a.length}
function rc(a){function b(){if(0<d.length){for(;" "===d[d.length-1];)d.pop();c.push({ta:d.filter(function(k,l){return 0===l%2}),Ha:d.filter(function(k,l){return 1===l%2})});d.length=0}}for(var c=[],d=[],e=0;e<a.length;){var f=d[d.length-1],g=qc(a,e,[","," ",">","+","~"]),h=g===e?a[e]:a.substring(e,g);if(","===h)b();else if(-1===[void 0," ",">","+","~"].indexOf(f)||" "!==h)" "===f&&-1!==[">","+","~"].indexOf(h)?d[d.length-1]=h:d.push(h);e=g+(g===e?1:0)}b();return c};function sc(a,b,c){var d=[];tc(a,b,c,d);return d}function tc(a,b,c,d){for(a=a.__shady_firstChild;a;a=a.__shady_nextSibling){var e;if(e=a.nodeType===Node.ELEMENT_NODE){e=a;var f=b,g=c,h=d,k=f(e);k&&h.push(e);g&&g(k)?e=k:(tc(e,f,g,h),e=void 0)}if(e)break}}
var uc={get firstElementChild(){var a=u(this);if(a&&void 0!==a.firstChild){for(a=this.__shady_firstChild;a&&a.nodeType!==Node.ELEMENT_NODE;)a=a.__shady_nextSibling;return a}return this.__shady_native_firstElementChild},get lastElementChild(){var a=u(this);if(a&&void 0!==a.lastChild){for(a=this.__shady_lastChild;a&&a.nodeType!==Node.ELEMENT_NODE;)a=a.__shady_previousSibling;return a}return this.__shady_native_lastElementChild},get children(){return x(this)?ta(Array.prototype.filter.call(va(this),function(a){return a.nodeType===
Node.ELEMENT_NODE})):this.__shady_native_children},get childElementCount(){var a=this.__shady_children;return a?a.length:0}},vc=A((uc.append=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];this.__shady_insertBefore(Aa.apply(null,r(b)),null)},uc.prepend=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];this.__shady_insertBefore(Aa.apply(null,r(b)),this.__shady_firstChild)},uc.replaceChildren=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];
for(;null!==(c=this.__shady_firstChild);)this.__shady_removeChild(c);this.__shady_insertBefore(Aa.apply(null,r(b)),null)},uc));
function wc(a,b){function c(e,f){return(e===a||-1===f.indexOf(":scope"))&&ma.call(e,f)}var d=rc(b);if(1>d.length)return[];for(b=Ba(sc(a,function(){return!0}).map(function(e){return Ba(d.map(function(f){var g=f.ta,h=g.length-1;return c(e,g[h])?{target:e,N:f,O:e,index:h}:[]}))}));b.some(function(e){return 0<e.index});)b=Ba(b.map(function(e){if(0>=e.index)return e;var f=e.target,g=e.O,h=e.N;e=e.index-1;var k=h.Ha[e],l=h.ta[e];if(" "===k){k=[];for(g=g.__shady_parentElement;g;g=g.__shady_parentElement)c(g,
l)&&k.push({target:f,N:h,O:g,index:e});return k}if(">"===k)return g=g.__shady_parentElement,c(g,l)?{target:f,N:h,O:g,index:e}:[];if("+"===k)return(g=g.__shady_previousElementSibling)&&c(g,l)?{target:f,N:h,O:g,index:e}:[];if("~"===k){k=[];for(g=g.__shady_previousElementSibling;g;g=g.__shady_previousElementSibling)c(g,l)&&k.push({target:f,N:h,O:g,index:e});return k}throw Error("Unrecognized combinator: '"+k+"'.");}));return Ca(b.map(function(e){return e.target}))}
var G=w.querySelectorImplementation,xc=A({querySelector:function(a){if("native"===G){var b=Array.prototype.slice.call((this instanceof ShadowRoot?this.host:this).__shady_native_querySelectorAll(a)),c=this.__shady_getRootNode();b=p(b);for(var d=b.next();!d.done;d=b.next())if(d=d.value,d.__shady_getRootNode()==c)return d;return null}if("selectorEngine"===G)return wc(this,a)[0]||null;if(void 0===G)return sc(this,function(e){return ma.call(e,a)},function(e){return!!e})[0]||null;throw Error("Unrecognized value of ShadyDOM.querySelectorImplementation: '"+
(G+"'"));},querySelectorAll:function(a,b){if(b||"native"===G){b=Array.prototype.slice.call((this instanceof ShadowRoot?this.host:this).__shady_native_querySelectorAll(a));var c=this.__shady_getRootNode();return ta(b.filter(function(d){return d.__shady_getRootNode()==c}))}if("selectorEngine"===G)return ta(wc(this,a));if(void 0===G)return ta(sc(this,function(d){return ma.call(d,a)}));throw Error("Unrecognized value of ShadyDOM.querySelectorImplementation: '"+(G+"'"));}}),yc=w.R&&!w.s?ya({},vc):vc;
ya(vc,xc);/*

Copyright (c) 2020 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
Code distributed by Google as part of the polymer project is also
subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/
var zc=A({after:function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];c=this.__shady_parentNode;if(null!==c){var d=this.__shady_nextSibling;c.__shady_insertBefore(Aa.apply(null,r(b)),d)}},before:function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];c=this.__shady_parentNode;null!==c&&c.__shady_insertBefore(Aa.apply(null,r(b)),this)},remove:function(){var a=this.__shady_parentNode;null!==a&&a.__shady_removeChild(this)},replaceWith:function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=
arguments[c];c=this.__shady_parentNode;if(null!==c){var d=this.__shady_nextSibling;c.__shady_removeChild(this);c.__shady_insertBefore(Aa.apply(null,r(b)),d)}}});var Ac=window.document;function Bc(a,b){if("slot"===b)a=a.__shady_parentNode,ja(a)&&F(u(a).root);else if("slot"===a.localName&&"name"===b&&(b=hc(a))){if(b.g){Cc(b);var c=a.Ca,d=Dc(a);if(d!==c){c=b.h[c];var e=c.indexOf(a);0<=e&&c.splice(e,1);c=b.h[d]||(b.h[d]=[]);c.push(a);1<c.length&&(b.h[d]=Ec(c))}}F(b)}}
var Fc=A({get previousElementSibling(){var a=u(this);if(a&&void 0!==a.previousSibling){for(a=this.__shady_previousSibling;a&&a.nodeType!==Node.ELEMENT_NODE;)a=a.__shady_previousSibling;return a}return this.__shady_native_previousElementSibling},get nextElementSibling(){var a=u(this);if(a&&void 0!==a.nextSibling){for(a=this.__shady_nextSibling;a&&a.nodeType!==Node.ELEMENT_NODE;)a=a.__shady_nextSibling;return a}return this.__shady_native_nextElementSibling},get slot(){return this.getAttribute("slot")},
set slot(a){this.__shady_setAttribute("slot",a)},get className(){return this.getAttribute("class")||""},set className(a){this.__shady_setAttribute("class",a)},setAttribute:function(a,b){this.ownerDocument!==Ac?this.__shady_native_setAttribute(a,b):Vb(this,a,b)||(this.__shady_native_setAttribute(a,b),Bc(this,a))},removeAttribute:function(a){this.ownerDocument!==Ac?this.__shady_native_removeAttribute(a):Vb(this,a,"")?""===this.getAttribute(a)&&this.__shady_native_removeAttribute(a):(this.__shady_native_removeAttribute(a),
Bc(this,a))}});w.R||Nb.forEach(function(a){Fc[a]=Pb(a)});
var Kc=A({attachShadow:function(a){if(!this)throw Error("Must provide a host.");if(!a)throw Error("Not enough arguments.");if(a.shadyUpgradeFragment&&!w.za){var b=a.shadyUpgradeFragment;b.__proto__=ShadowRoot.prototype;Gc(b,this,a);Hc(b,b);a=b.__noInsertionPoint?null:b.querySelectorAll("slot");b.__noInsertionPoint=void 0;if(a&&a.length){var c=b;ic(c);c.i.push.apply(c.i,r(a));F(b)}b.host.__shady_native_appendChild(b)}else b=new Ic(Jc,this,a);return this.__CE_shadowRoot=b},get shadowRoot(){var a=u(this);
return a&&a.Pa||null}});ya(Fc,Kc);var Lc=document.implementation.createHTMLDocument("inert"),Mc=A({get innerHTML(){return x(this)?Sa("template"===this.localName?this.content:this,va):this.__shady_native_innerHTML},set innerHTML(a){if("template"===this.localName)this.__shady_native_innerHTML=a;else{dc(this);var b=this.localName||"div";b=this.namespaceURI&&this.namespaceURI!==Lc.namespaceURI?Lc.createElementNS(this.namespaceURI,b):Lc.createElement(b);for(w.j?b.__shady_native_innerHTML=a:b.innerHTML=a;a=b.__shady_firstChild;)this.__shady_insertBefore(a)}}});var Nc=A({blur:function(){var a=u(this);(a=(a=a&&a.root)&&a.activeElement)?a.__shady_blur():this.__shady_native_blur()}});w.R||Ob.forEach(function(a){Nc[a]=Pb(a)});var Oc=A({assignedNodes:function(a){if("slot"===this.localName){var b=this.__shady_getRootNode();b&&y(b)&&nc(b);return(b=u(this))?(a&&a.flatten?b.L:b.assignedNodes)||[]:[]}},addEventListener:function(a,b,c){if("slot"!==this.localName||"slotchange"===a)Fb.call(this,a,b,c);else{"object"!==typeof c&&(c={capture:!!c});var d=this.__shady_parentNode;if(!d)throw Error("ShadyDOM cannot attach event to slot unless it has a `parentNode`");c.G=this;d.__shady_addEventListener(a,b,c)}},removeEventListener:function(a,
b,c){if("slot"!==this.localName||"slotchange"===a)Gb.call(this,a,b,c);else{"object"!==typeof c&&(c={capture:!!c});var d=this.__shady_parentNode;if(!d)throw Error("ShadyDOM cannot attach event to slot unless it has a `parentNode`");c.G=this;d.__shady_removeEventListener(a,b,c)}}});var Pc=A({getElementById:function(a){return""===a?null:sc(this,function(b){return b.id==a},function(b){return!!b})[0]||null}});function Qc(a,b){for(var c;b&&!a.has(c=b.__shady_getRootNode());)b=c.host;return b}function Rc(a){var b=new Set;for(b.add(a);y(a)&&a.host;)a=a.host.__shady_getRootNode(),b.add(a);return b}
var Sc="__shady_native_"+ia(),Tc=A({get activeElement(){var a=w.j?document.__shady_native_activeElement:document.activeElement;if(!a||!a.nodeType)return null;var b=!!y(this);if(!(this===document||b&&this.host!==a&&this.host.__shady_native_contains(a)))return null;for(b=hc(a);b&&b!==this;)a=b.host,b=hc(a);return this===document?b?null:a:b===this?a:null},elementsFromPoint:function(a,b){a=document[Sc](a,b);if(this===document&&w.useNativeDocumentEFP)return a;a=[].slice.call(a);b=Rc(this);for(var c=new Set,
d=0;d<a.length;d++)c.add(Qc(b,a[d]));var e=[];c.forEach(function(f){return e.push(f)});return e},elementFromPoint:function(a,b){return this===document&&w.useNativeDocumentEFP?this.__shady_native_elementFromPoint(a,b):this.__shady_elementsFromPoint(a,b)[0]||null}});var Uc=window.document,Vc=A({importNode:function(a,b){if(a.ownerDocument!==Uc||"template"===a.localName)return this.__shady_native_importNode(a,b);var c=this.__shady_native_importNode(a,!1);if(b)for(a=a.__shady_firstChild;a;a=a.__shady_nextSibling)b=this.__shady_importNode(a,!0),c.__shady_appendChild(b);return c}});var Wc=A({dispatchEvent:Db,addEventListener:Fb.bind(window),removeEventListener:Gb.bind(window)});var Xc={};Object.getOwnPropertyDescriptor(HTMLElement.prototype,"parentElement")&&(Xc.parentElement=mc.parentElement);Object.getOwnPropertyDescriptor(HTMLElement.prototype,"contains")&&(Xc.contains=mc.contains);Object.getOwnPropertyDescriptor(HTMLElement.prototype,"children")&&(Xc.children=vc.children);Object.getOwnPropertyDescriptor(HTMLElement.prototype,"innerHTML")&&(Xc.innerHTML=Mc.innerHTML);Object.getOwnPropertyDescriptor(HTMLElement.prototype,"className")&&(Xc.className=Fc.className);
var H={EventTarget:[Tb],Node:[mc,window.EventTarget?null:Tb],Text:[oc],Comment:[oc],CDATASection:[oc],ProcessingInstruction:[oc],Element:[Fc,vc,zc,oc,!w.j||"innerHTML"in Element.prototype?Mc:null,window.HTMLSlotElement?null:Oc],HTMLElement:[Nc,Xc],HTMLSlotElement:[Oc],DocumentFragment:[yc,Pc],Document:[Vc,yc,Pc,Tc],Window:[Wc],CharacterData:[zc],XMLHttpRequest:[window.EventTarget?null:Tb]},Yc=w.j?null:["innerHTML","textContent"];
function I(a,b,c,d){b.forEach(function(e){return a&&e&&z(a,e,c,d)})}function Zc(a){var b=a?null:Yc,c;for(c in H)I(window[c]&&window[c].prototype,H[c],a,b)}["Text","Comment","CDATASection","ProcessingInstruction"].forEach(function(a){var b=window[a],c=Object.create(b.prototype);c.__shady_protoIsPatched=!0;I(c,H.EventTarget);I(c,H.Node);H[a]&&I(c,H[a]);b.prototype.__shady_patchedProto=c});
function $c(a){a.__shady_protoIsPatched=!0;I(a,H.EventTarget);I(a,H.Node);I(a,H.Element);I(a,H.HTMLElement);I(a,H.HTMLSlotElement);return a};var ad=w.ma,bd=w.j;function cd(a,b){if(ad&&!a.__shady_protoIsPatched&&!y(a)){var c=Object.getPrototypeOf(a),d=c.hasOwnProperty("__shady_patchedProto")&&c.__shady_patchedProto;d||(d=Object.create(c),$c(d),c.__shady_patchedProto=d);Object.setPrototypeOf(a,d)}bd||(1===b?ib(a):2===b&&jb(a))}
function dd(a,b,c,d){cd(a,1);d=d||null;var e=t(a),f=d?t(d):null;e.previousSibling=d?f.previousSibling:b.__shady_lastChild;if(f=u(e.previousSibling))f.nextSibling=a;if(f=u(e.nextSibling=d))f.previousSibling=a;e.parentNode=b;d?d===c.firstChild&&(c.firstChild=a):(c.lastChild=a,c.firstChild||(c.firstChild=a));c.childNodes=null}
function jc(a,b,c){cd(b,2);var d=t(b);void 0!==d.firstChild&&(d.childNodes=null);if(a.nodeType===Node.DOCUMENT_FRAGMENT_NODE)for(a=a.__shady_native_firstChild;a;a=a.__shady_native_nextSibling)dd(a,b,d,c);else dd(a,b,d,c)}
function lc(a,b){var c=t(a);b=t(b);a===b.firstChild&&(b.firstChild=c.nextSibling);a===b.lastChild&&(b.lastChild=c.previousSibling);a=c.previousSibling;var d=c.nextSibling;a&&(t(a).nextSibling=d);d&&(t(d).previousSibling=a);c.parentNode=c.previousSibling=c.nextSibling=void 0;void 0!==b.childNodes&&(b.childNodes=null)}
function Hc(a,b){var c=t(a);if(b||void 0===c.firstChild){c.childNodes=null;var d=c.firstChild=a.__shady_native_firstChild;c.lastChild=a.__shady_native_lastChild;cd(a,2);c=d;for(d=void 0;c;c=c.__shady_native_nextSibling){var e=t(c);e.parentNode=b||a;e.nextSibling=c.__shady_native_nextSibling;e.previousSibling=d||null;d=c;cd(c,1)}}};var ed=A({addEventListener:function(a,b,c){"object"!==typeof c&&(c={capture:!!c});c.G=c.G||this;this.host.__shady_addEventListener(a,b,c)},removeEventListener:function(a,b,c){"object"!==typeof c&&(c={capture:!!c});c.G=c.G||this;this.host.__shady_removeEventListener(a,b,c)}});function fd(a,b){z(a,ed,b);z(a,Tc,b);z(a,Mc,b);z(a,vc,b);w.s&&!b?(z(a,mc,b),z(a,Pc,b)):w.j||(z(a,fb),z(a,db),z(a,eb))};var Jc={},J=w.deferConnectionCallbacks&&"loading"===document.readyState,gd;function hd(a){var b=[];do b.unshift(a);while(a=a.__shady_parentNode);return b}function Ic(a,b,c){if(a!==Jc)throw new TypeError("Illegal constructor");this.g=null;Gc(this,b,c)}
function Gc(a,b,c){a.host=b;a.mode=c&&c.mode;Hc(a.host);b=t(a.host);b.root=a;b.Pa="closed"!==a.mode?a:null;b=t(a);b.firstChild=b.lastChild=b.parentNode=b.nextSibling=b.previousSibling=null;if(w.preferPerformance)for(;b=a.host.__shady_native_firstChild;)a.host.__shady_native_removeChild(b);else F(a)}function F(a){a.K||(a.K=!0,Fa(function(){return nc(a)}))}
function nc(a){var b;if(b=a.K){for(var c;a;)a:{a.K&&(c=a),b=a;a=b.host.__shady_getRootNode();if(y(a)&&(b=u(b.host))&&0<b.U)break a;a=void 0}b=c}(c=b)&&c._renderSelf()}
Ic.prototype._renderSelf=function(){var a=J;J=!0;this.K=!1;if(this.g){Cc(this);for(var b=0,c;b<this.g.length;b++){c=this.g[b];var d=u(c),e=d.assignedNodes;d.assignedNodes=[];d.L=[];if(d.ra=e)for(d=0;d<e.length;d++){var f=u(e[d]);f.ha=f.assignedSlot;f.assignedSlot===c&&(f.assignedSlot=null)}}for(b=this.host.__shady_firstChild;b;b=b.__shady_nextSibling)id(this,b);for(b=0;b<this.g.length;b++){c=this.g[b];e=u(c);if(!e.assignedNodes.length)for(d=c.__shady_firstChild;d;d=d.__shady_nextSibling)id(this,d,
c);(d=(d=u(c.__shady_parentNode))&&d.root)&&(ka(d)||d.K)&&d._renderSelf();jd(this,e.L,e.assignedNodes);if(d=e.ra){for(f=0;f<d.length;f++)u(d[f]).ha=null;e.ra=null;d.length>e.assignedNodes.length&&(e.ja=!0)}e.ja&&(e.ja=!1,kd(this,c))}c=this.g;b=[];for(e=0;e<c.length;e++)d=c[e].__shady_parentNode,(f=u(d))&&f.root||!(0>b.indexOf(d))||b.push(d);for(c=0;c<b.length;c++){f=b[c];e=f===this?this.host:f;d=[];for(f=f.__shady_firstChild;f;f=f.__shady_nextSibling)if("slot"==f.localName)for(var g=u(f).L,h=0;h<
g.length;h++)d.push(g[h]);else d.push(f);f=ua(e);g=Rb(d,d.length,f,f.length);for(var k=h=0,l=void 0;h<g.length&&(l=g[h]);h++){for(var m=0,q=void 0;m<l.S.length&&(q=l.S[m]);m++)q.__shady_native_parentNode===e&&e.__shady_native_removeChild(q),f.splice(l.index+k,1);k-=l.Z}k=0;for(l=void 0;k<g.length&&(l=g[k]);k++)for(h=f[l.index],m=l.index;m<l.index+l.Z;m++)q=d[m],e.__shady_native_insertBefore(q,h),f.splice(m,0,q)}}if(!w.preferPerformance&&!this.qa)for(b=this.host.__shady_firstChild;b;b=b.__shady_nextSibling)c=
u(b),b.__shady_native_parentNode!==this.host||"slot"!==b.localName&&c.assignedSlot||this.host.__shady_native_removeChild(b);this.qa=!0;J=a;gd&&gd()};function id(a,b,c){var d=t(b),e=d.ha;d.ha=null;c||(c=(a=a.h[b.__shady_slot||"__catchall"])&&a[0]);c?(t(c).assignedNodes.push(b),d.assignedSlot=c):d.assignedSlot=void 0;e!==d.assignedSlot&&d.assignedSlot&&(t(d.assignedSlot).ja=!0)}
function jd(a,b,c){for(var d=0,e=void 0;d<c.length&&(e=c[d]);d++)if("slot"==e.localName){var f=u(e).assignedNodes;f&&f.length&&jd(a,b,f)}else b.push(c[d])}function kd(a,b){b.__shady_native_dispatchEvent(new Event("slotchange"));b=u(b);b.assignedSlot&&kd(a,b.assignedSlot)}function ic(a){a.i=a.i||[];a.g=a.g||[];a.h=a.h||{}}
function Cc(a){if(a.i&&a.i.length){for(var b=a.i,c,d=0;d<b.length;d++){var e=b[d];Hc(e);var f=e.__shady_parentNode;Hc(f);f=u(f);f.U=(f.U||0)+1;f=Dc(e);a.h[f]?(c=c||{},c[f]=!0,a.h[f].push(e)):a.h[f]=[e];a.g.push(e)}if(c)for(var g in c)a.h[g]=Ec(a.h[g]);a.i=[]}}function Dc(a){var b=a.name||a.getAttribute("name")||"__catchall";return a.Ca=b}
function Ec(a){return a.sort(function(b,c){b=hd(b);for(var d=hd(c),e=0;e<b.length;e++){c=b[e];var f=d[e];if(c!==f)return b=va(c.__shady_parentNode),b.indexOf(c)-b.indexOf(f)}})}
function kc(a,b){if(a.g){Cc(a);var c=a.h,d;for(d in c)for(var e=c[d],f=0;f<e.length;f++){var g=e[f];if(sa(b,g)){e.splice(f,1);var h=a.g.indexOf(g);0<=h&&(a.g.splice(h,1),(h=u(g.__shady_parentNode))&&h.U&&h.U--);f--;g=u(g);if(h=g.L)for(var k=0;k<h.length;k++){var l=h[k],m=l.__shady_native_parentNode;m&&m.__shady_native_removeChild(l)}g.L=[];g.assignedNodes=[];h=!0}}return h}}function ka(a){Cc(a);return!(!a.g||!a.g.length)}
(function(a){a.__proto__=DocumentFragment.prototype;fd(a,"__shady_");fd(a);Object.defineProperties(a,{nodeType:{value:Node.DOCUMENT_FRAGMENT_NODE,configurable:!0},nodeName:{value:"#document-fragment",configurable:!0},nodeValue:{value:null,configurable:!0}});["localName","namespaceURI","prefix"].forEach(function(b){Object.defineProperty(a,b,{value:void 0,configurable:!0})});["ownerDocument","baseURI","isConnected"].forEach(function(b){Object.defineProperty(a,b,{get:function(){return this.host[b]},
configurable:!0})})})(Ic.prototype);
if(window.customElements&&window.customElements.define&&w.ka&&!w.preferPerformance){var ld=new Map;gd=function(){var a=[];ld.forEach(function(d,e){a.push([e,d])});ld.clear();for(var b=0;b<a.length;b++){var c=a[b][0];a[b][1]?c.__shadydom_connectedCallback():c.__shadydom_disconnectedCallback()}};J&&document.addEventListener("readystatechange",function(){J=!1;gd()},{once:!0});var md=function(a,b,c){var d=0,e="__isConnected"+d++;if(b||c)a.prototype.connectedCallback=a.prototype.__shadydom_connectedCallback=
function(){J?ld.set(this,!0):this[e]||(this[e]=!0,b&&b.call(this))},a.prototype.disconnectedCallback=a.prototype.__shadydom_disconnectedCallback=function(){J?this.isConnected||ld.set(this,!1):this[e]&&(this[e]=!1,c&&c.call(this))};return a},nd=window.customElements.define,od=function(a,b){var c=b.prototype.connectedCallback,d=b.prototype.disconnectedCallback;nd.call(window.customElements,a,md(b,c,d));b.prototype.connectedCallback=c;b.prototype.disconnectedCallback=d};window.customElements.define=
od;Object.defineProperty(window.CustomElementRegistry.prototype,"define",{value:od,configurable:!0})}function hc(a){a=a.__shady_getRootNode();if(y(a))return a};function pd(a){this.node=a}n=pd.prototype;n.addEventListener=function(a,b,c){return this.node.__shady_addEventListener(a,b,c)};n.removeEventListener=function(a,b,c){return this.node.__shady_removeEventListener(a,b,c)};n.appendChild=function(a){return this.node.__shady_appendChild(a)};n.insertBefore=function(a,b){return this.node.__shady_insertBefore(a,b)};n.removeChild=function(a){return this.node.__shady_removeChild(a)};n.replaceChild=function(a,b){return this.node.__shady_replaceChild(a,b)};
n.cloneNode=function(a){return this.node.__shady_cloneNode(a)};n.getRootNode=function(a){return this.node.__shady_getRootNode(a)};n.contains=function(a){return this.node.__shady_contains(a)};n.dispatchEvent=function(a){return this.node.__shady_dispatchEvent(a)};n.setAttribute=function(a,b){this.node.__shady_setAttribute(a,b)};n.getAttribute=function(a){return this.node.__shady_native_getAttribute(a)};n.removeAttribute=function(a){this.node.__shady_removeAttribute(a)};n.attachShadow=function(a){return this.node.__shady_attachShadow(a)};
n.focus=function(){this.node.__shady_native_focus()};n.blur=function(){this.node.__shady_blur()};n.importNode=function(a,b){if(this.node.nodeType===Node.DOCUMENT_NODE)return this.node.__shady_importNode(a,b)};n.getElementById=function(a){if(this.node.nodeType===Node.DOCUMENT_NODE)return this.node.__shady_getElementById(a)};n.elementsFromPoint=function(a,b){return this.node.__shady_elementsFromPoint(a,b)};n.elementFromPoint=function(a,b){return this.node.__shady_elementFromPoint(a,b)};
n.querySelector=function(a){return this.node.__shady_querySelector(a)};n.querySelectorAll=function(a,b){return this.node.__shady_querySelectorAll(a,b)};n.assignedNodes=function(a){if("slot"===this.node.localName)return this.node.__shady_assignedNodes(a)};n.append=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];return this.node.__shady_append.apply(this.node,r(b))};
n.prepend=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];return this.node.__shady_prepend.apply(this.node,r(b))};n.after=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];return this.node.__shady_after.apply(this.node,r(b))};n.before=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];return this.node.__shady_before.apply(this.node,r(b))};n.remove=function(){return this.node.__shady_remove()};
n.replaceWith=function(a){for(var b=[],c=0;c<arguments.length;++c)b[c]=arguments[c];return this.node.__shady_replaceWith.apply(this.node,r(b))};
ca.Object.defineProperties(pd.prototype,{activeElement:{configurable:!0,enumerable:!0,get:function(){if(y(this.node)||this.node.nodeType===Node.DOCUMENT_NODE)return this.node.__shady_activeElement}},_activeElement:{configurable:!0,enumerable:!0,get:function(){return this.activeElement}},host:{configurable:!0,enumerable:!0,get:function(){if(y(this.node))return this.node.host}},parentNode:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_parentNode}},firstChild:{configurable:!0,
enumerable:!0,get:function(){return this.node.__shady_firstChild}},lastChild:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_lastChild}},nextSibling:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_nextSibling}},previousSibling:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_previousSibling}},childNodes:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_childNodes}},parentElement:{configurable:!0,enumerable:!0,
get:function(){return this.node.__shady_parentElement}},firstElementChild:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_firstElementChild}},lastElementChild:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_lastElementChild}},nextElementSibling:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_nextElementSibling}},previousElementSibling:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_previousElementSibling}},
children:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_children}},childElementCount:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_childElementCount}},shadowRoot:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_shadowRoot}},assignedSlot:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_assignedSlot}},isConnected:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_isConnected}},innerHTML:{configurable:!0,
enumerable:!0,get:function(){return this.node.__shady_innerHTML},set:function(a){this.node.__shady_innerHTML=a}},textContent:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_textContent},set:function(a){this.node.__shady_textContent=a}},slot:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_slot},set:function(a){this.node.__shady_slot=a}},className:{configurable:!0,enumerable:!0,get:function(){return this.node.__shady_className},set:function(a){this.node.__shady_className=
a}}});function qd(a){Object.defineProperty(pd.prototype,a,{get:function(){return this.node["__shady_"+a]},set:function(b){this.node["__shady_"+a]=b},configurable:!0})}Nb.forEach(function(a){return qd(a)});Ob.forEach(function(a){return qd(a)});var rd=new WeakMap;function sd(a){if(y(a)||a instanceof pd)return a;var b=rd.get(a);b||(b=new pd(a),rd.set(a,b));return b};if(w.ka){var td=w.j?function(a){return a}:function(a){jb(a);ib(a);return a},ShadyDOM={inUse:w.ka,patch:td,isShadyRoot:y,enqueue:Fa,flush:Ga,flushInitial:function(a){!a.qa&&a.K&&nc(a)},settings:w,filterMutations:La,observeChildren:Ja,unobserveChildren:Ka,deferConnectionCallbacks:w.deferConnectionCallbacks,preferPerformance:w.preferPerformance,handlesDynamicScoping:!0,wrap:w.s?sd:td,wrapIfNeeded:!0===w.s?sd:function(a){return a},Wrapper:pd,composedPath:sb,noPatch:w.s,patchOnDemand:w.ma,nativeMethods:Ua,
nativeTree:Va,patchElementProto:$c,querySelectorImplementation:w.querySelectorImplementation};window.ShadyDOM=ShadyDOM;bb();Zc("__shady_");Object.defineProperty(document,"_activeElement",Tc.activeElement);z(Window.prototype,Wc,"__shady_");w.s?w.ma&&z(Element.prototype,Kc):(Zc(),Mb());Hb();window.Event=Jb;window.CustomEvent=Kb;window.MouseEvent=Lb;window.ShadowRoot=Ic};/*

 Copyright (c) 2016 The Polymer Project Authors. All rights reserved.
 This code may only be used under the BSD style license found at
 http://polymer.github.io/LICENSE.txt The complete set of authors may be found
 at http://polymer.github.io/AUTHORS.txt The complete set of contributors may
 be found at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by
 Google as part of the polymer project is also subject to an additional IP
 rights grant found at http://polymer.github.io/PATENTS.txt
*/
var ud=window.Document.prototype.createElement,vd=window.Document.prototype.createElementNS,wd=window.Document.prototype.importNode,xd=window.Document.prototype.prepend,yd=window.Document.prototype.append,zd=window.DocumentFragment.prototype.prepend,Ad=window.DocumentFragment.prototype.append,Bd=window.Node.prototype.cloneNode,Cd=window.Node.prototype.appendChild,Dd=window.Node.prototype.insertBefore,Ed=window.Node.prototype.removeChild,Fd=window.Node.prototype.replaceChild,Gd=Object.getOwnPropertyDescriptor(window.Node.prototype,
"textContent"),Hd=window.Element.prototype.attachShadow,Id=Object.getOwnPropertyDescriptor(window.Element.prototype,"innerHTML"),Jd=window.Element.prototype.getAttribute,Kd=window.Element.prototype.setAttribute,Ld=window.Element.prototype.removeAttribute,Md=window.Element.prototype.getAttributeNS,Nd=window.Element.prototype.setAttributeNS,Od=window.Element.prototype.removeAttributeNS,Pd=window.Element.prototype.insertAdjacentElement,Qd=window.Element.prototype.insertAdjacentHTML,Rd=window.Element.prototype.prepend,
Sd=window.Element.prototype.append,Td=window.Element.prototype.before,Ud=window.Element.prototype.after,Vd=window.Element.prototype.replaceWith,Wd=window.Element.prototype.remove,Xd=window.HTMLElement,Yd=Object.getOwnPropertyDescriptor(window.HTMLElement.prototype,"innerHTML"),Zd=window.HTMLElement.prototype.insertAdjacentElement,$d=window.HTMLElement.prototype.insertAdjacentHTML;var ae=new Set;"annotation-xml color-profile font-face font-face-src font-face-uri font-face-format font-face-name missing-glyph".split(" ").forEach(function(a){return ae.add(a)});function be(a){var b=ae.has(a);a=/^[a-z][.0-9_a-z]*-[-.0-9_a-z]*$/.test(a);return!b&&a}var ce=document.contains?document.contains.bind(document):document.documentElement.contains.bind(document.documentElement);
function K(a){var b=a.isConnected;if(void 0!==b)return b;if(ce(a))return!0;for(;a&&!(a.__CE_isImportDocument||a instanceof Document);)a=a.parentNode||(window.ShadowRoot&&a instanceof ShadowRoot?a.host:void 0);return!(!a||!(a.__CE_isImportDocument||a instanceof Document))}function de(a){var b=a.children;if(b)return Array.prototype.slice.call(b);b=[];for(a=a.firstChild;a;a=a.nextSibling)a.nodeType===Node.ELEMENT_NODE&&b.push(a);return b}
function ee(a,b){for(;b&&b!==a&&!b.nextSibling;)b=b.parentNode;return b&&b!==a?b.nextSibling:null}
function fe(a,b,c){for(var d=a;d;){if(d.nodeType===Node.ELEMENT_NODE){var e=d;b(e);var f=e.localName;if("link"===f&&"import"===e.getAttribute("rel")){d=e.import;void 0===c&&(c=new Set);if(d instanceof Node&&!c.has(d))for(c.add(d),d=d.firstChild;d;d=d.nextSibling)fe(d,b,c);d=ee(a,e);continue}else if("template"===f){d=ee(a,e);continue}if(e=e.__CE_shadowRoot)for(e=e.firstChild;e;e=e.nextSibling)fe(e,b,c)}d=d.firstChild?d.firstChild:ee(a,d)}};function ge(){var a=!(null===L||void 0===L||!L.noDocumentConstructionObserver),b=!(null===L||void 0===L||!L.shadyDomFastWalk);this.M=[];this.g=[];this.I=!1;this.shadyDomFastWalk=b;this.Wa=!a}function he(a,b,c,d){var e=window.ShadyDOM;if(a.shadyDomFastWalk&&e&&e.inUse){if(b.nodeType===Node.ELEMENT_NODE&&c(b),b.querySelectorAll)for(a=e.nativeMethods.querySelectorAll.call(b,"*"),b=0;b<a.length;b++)c(a[b])}else fe(b,c,d)}function ie(a,b){a.I=!0;a.M.push(b)}function je(a,b){a.I=!0;a.g.push(b)}
function ke(a,b){a.I&&he(a,b,function(c){return le(a,c)})}function le(a,b){if(a.I&&!b.__CE_patched){b.__CE_patched=!0;for(var c=0;c<a.M.length;c++)a.M[c](b);for(c=0;c<a.g.length;c++)a.g[c](b)}}function M(a,b){var c=[];he(a,b,function(e){return c.push(e)});for(b=0;b<c.length;b++){var d=c[b];1===d.__CE_state?a.connectedCallback(d):me(a,d)}}function N(a,b){var c=[];he(a,b,function(e){return c.push(e)});for(b=0;b<c.length;b++){var d=c[b];1===d.__CE_state&&a.disconnectedCallback(d)}}
function O(a,b,c){c=void 0===c?{}:c;var d=c.Xa,e=c.upgrade||function(g){return me(a,g)},f=[];he(a,b,function(g){a.I&&le(a,g);if("link"===g.localName&&"import"===g.getAttribute("rel")){var h=g.import;h instanceof Node&&(h.__CE_isImportDocument=!0,h.__CE_registry=document.__CE_registry);h&&"complete"===h.readyState?h.__CE_documentLoadHandled=!0:g.addEventListener("load",function(){var k=g.import;if(!k.__CE_documentLoadHandled){k.__CE_documentLoadHandled=!0;var l=new Set;d&&(d.forEach(function(m){return l.add(m)}),
l.delete(k));O(a,k,{Xa:l,upgrade:e})}})}else f.push(g)},d);for(b=0;b<f.length;b++)e(f[b])}
function me(a,b){try{var c=b.ownerDocument,d=c.__CE_registry;var e=d&&(c.defaultView||c.__CE_isImportDocument)?ne(d,b.localName):void 0;if(e&&void 0===b.__CE_state){e.constructionStack.push(b);try{try{if(new e.constructorFunction!==b)throw Error("The custom element constructor did not produce the element being upgraded.");}finally{e.constructionStack.pop()}}catch(k){throw b.__CE_state=2,k;}b.__CE_state=1;b.__CE_definition=e;if(e.attributeChangedCallback&&b.hasAttributes()){var f=e.observedAttributes;
for(e=0;e<f.length;e++){var g=f[e],h=b.getAttribute(g);null!==h&&a.attributeChangedCallback(b,g,null,h,null)}}K(b)&&a.connectedCallback(b)}}catch(k){oe(k)}}ge.prototype.connectedCallback=function(a){var b=a.__CE_definition;if(b.connectedCallback)try{b.connectedCallback.call(a)}catch(c){oe(c)}};ge.prototype.disconnectedCallback=function(a){var b=a.__CE_definition;if(b.disconnectedCallback)try{b.disconnectedCallback.call(a)}catch(c){oe(c)}};
ge.prototype.attributeChangedCallback=function(a,b,c,d,e){var f=a.__CE_definition;if(f.attributeChangedCallback&&-1<f.observedAttributes.indexOf(b))try{f.attributeChangedCallback.call(a,b,c,d,e)}catch(g){oe(g)}};
function pe(a,b,c,d){var e=b.__CE_registry;if(e&&(null===d||"http://www.w3.org/1999/xhtml"===d)&&(e=ne(e,c)))try{var f=new e.constructorFunction;if(void 0===f.__CE_state||void 0===f.__CE_definition)throw Error("Failed to construct '"+c+"': The returned value was not constructed with the HTMLElement constructor.");if("http://www.w3.org/1999/xhtml"!==f.namespaceURI)throw Error("Failed to construct '"+c+"': The constructed element's namespace must be the HTML namespace.");if(f.hasAttributes())throw Error("Failed to construct '"+
c+"': The constructed element must not have any attributes.");if(null!==f.firstChild)throw Error("Failed to construct '"+c+"': The constructed element must not have any children.");if(null!==f.parentNode)throw Error("Failed to construct '"+c+"': The constructed element must not have a parent node.");if(f.ownerDocument!==b)throw Error("Failed to construct '"+c+"': The constructed element's owner document is incorrect.");if(f.localName!==c)throw Error("Failed to construct '"+c+"': The constructed element's local name is incorrect.");
return f}catch(g){return oe(g),b=null===d?ud.call(b,c):vd.call(b,d,c),Object.setPrototypeOf(b,HTMLUnknownElement.prototype),b.__CE_state=2,b.__CE_definition=void 0,le(a,b),b}b=null===d?ud.call(b,c):vd.call(b,d,c);le(a,b);return b}
function oe(a){var b="",c="",d=0,e=0;a instanceof Error?(b=a.message,c=a.sourceURL||a.fileName||"",d=a.line||a.lineNumber||0,e=a.column||a.columnNumber||0):b="Uncaught "+String(a);var f=void 0;void 0===ErrorEvent.prototype.initErrorEvent?f=new ErrorEvent("error",{cancelable:!0,message:b,filename:c,lineno:d,colno:e,error:a}):(f=document.createEvent("ErrorEvent"),f.initErrorEvent("error",!1,!0,b,c,d),f.preventDefault=function(){Object.defineProperty(this,"defaultPrevented",{configurable:!0,get:function(){return!0}})});
void 0===f.error&&Object.defineProperty(f,"error",{configurable:!0,enumerable:!0,get:function(){return a}});window.dispatchEvent(f);f.defaultPrevented||console.error(a)};function qe(){var a=this;this.g=void 0;this.sa=new Promise(function(b){a.h=b})}qe.prototype.resolve=function(a){if(this.g)throw Error("Already resolved.");this.g=a;this.h(a)};function re(a){var b=document;this.J=void 0;this.D=a;this.g=b;O(this.D,this.g);"loading"===this.g.readyState&&(this.J=new MutationObserver(this.h.bind(this)),this.J.observe(this.g,{childList:!0,subtree:!0}))}function se(a){a.J&&a.J.disconnect()}re.prototype.h=function(a){var b=this.g.readyState;"interactive"!==b&&"complete"!==b||se(this);for(b=0;b<a.length;b++)for(var c=a[b].addedNodes,d=0;d<c.length;d++)O(this.D,c[d])};function P(a){this.W=new Map;this.X=new Map;this.oa=new Map;this.ga=!1;this.ia=new Map;this.V=function(b){return b()};this.H=!1;this.Y=[];this.D=a;this.pa=a.Wa?new re(a):void 0}n=P.prototype;n.Na=function(a,b){var c=this;if(!(b instanceof Function))throw new TypeError("Custom element constructor getters must be functions.");te(this,a);this.W.set(a,b);this.Y.push(a);this.H||(this.H=!0,this.V(function(){return ue(c)}))};
n.define=function(a,b){var c=this;if(!(b instanceof Function))throw new TypeError("Custom element constructors must be functions.");te(this,a);ve(this,a,b);this.Y.push(a);this.H||(this.H=!0,this.V(function(){return ue(c)}))};function te(a,b){if(!be(b))throw new SyntaxError("The element name '"+b+"' is not valid.");if(ne(a,b))throw Error("A custom element with name '"+(b+"' has already been defined."));if(a.ga)throw Error("A custom element is already being defined.");}
function ve(a,b,c){a.ga=!0;var d;try{var e=c.prototype;if(!(e instanceof Object))throw new TypeError("The custom element constructor's prototype is not an object.");var f=function(m){var q=e[m];if(void 0!==q&&!(q instanceof Function))throw Error("The '"+m+"' callback must be a function.");return q};var g=f("connectedCallback");var h=f("disconnectedCallback");var k=f("adoptedCallback");var l=(d=f("attributeChangedCallback"))&&c.observedAttributes||[]}catch(m){throw m;}finally{a.ga=!1}c={localName:b,
constructorFunction:c,connectedCallback:g,disconnectedCallback:h,adoptedCallback:k,attributeChangedCallback:d,observedAttributes:l,constructionStack:[]};a.X.set(b,c);a.oa.set(c.constructorFunction,c);return c}n.upgrade=function(a){O(this.D,a)};
function ue(a){if(!1!==a.H){a.H=!1;for(var b=[],c=a.Y,d=new Map,e=0;e<c.length;e++)d.set(c[e],[]);O(a.D,document,{upgrade:function(k){if(void 0===k.__CE_state){var l=k.localName,m=d.get(l);m?m.push(k):a.X.has(l)&&b.push(k)}}});for(e=0;e<b.length;e++)me(a.D,b[e]);for(e=0;e<c.length;e++){for(var f=c[e],g=d.get(f),h=0;h<g.length;h++)me(a.D,g[h]);(f=a.ia.get(f))&&f.resolve(void 0)}c.length=0}}n.get=function(a){if(a=ne(this,a))return a.constructorFunction};
n.whenDefined=function(a){if(!be(a))return Promise.reject(new SyntaxError("'"+a+"' is not a valid custom element name."));var b=this.ia.get(a);if(b)return b.sa;b=new qe;this.ia.set(a,b);var c=this.X.has(a)||this.W.has(a);a=-1===this.Y.indexOf(a);c&&a&&b.resolve(void 0);return b.sa};n.polyfillWrapFlushCallback=function(a){this.pa&&se(this.pa);var b=this.V;this.V=function(c){return a(function(){return b(c)})}};
function ne(a,b){var c=a.X.get(b);if(c)return c;if(c=a.W.get(b)){a.W.delete(b);try{return ve(a,b,c())}catch(d){oe(d)}}}P.prototype.define=P.prototype.define;P.prototype.upgrade=P.prototype.upgrade;P.prototype.get=P.prototype.get;P.prototype.whenDefined=P.prototype.whenDefined;P.prototype.polyfillDefineLazy=P.prototype.Na;P.prototype.polyfillWrapFlushCallback=P.prototype.polyfillWrapFlushCallback;function we(a,b,c){function d(e){return function(f){for(var g=[],h=0;h<arguments.length;++h)g[h]=arguments[h];h=[];for(var k=[],l=0;l<g.length;l++){var m=g[l];m instanceof Element&&K(m)&&k.push(m);if(m instanceof DocumentFragment)for(m=m.firstChild;m;m=m.nextSibling)h.push(m);else h.push(m)}e.apply(this,g);for(g=0;g<k.length;g++)N(a,k[g]);if(K(this))for(g=0;g<h.length;g++)k=h[g],k instanceof Element&&M(a,k)}}void 0!==c.prepend&&(b.prepend=d(c.prepend));void 0!==c.append&&(b.append=d(c.append))};function xe(a){Document.prototype.createElement=function(b){return pe(a,this,b,null)};Document.prototype.importNode=function(b,c){b=wd.call(this,b,!!c);this.__CE_registry?O(a,b):ke(a,b);return b};Document.prototype.createElementNS=function(b,c){return pe(a,this,c,b)};we(a,Document.prototype,{prepend:xd,append:yd})};function ye(a){function b(d){return function(e){for(var f=[],g=0;g<arguments.length;++g)f[g]=arguments[g];g=[];for(var h=[],k=0;k<f.length;k++){var l=f[k];l instanceof Element&&K(l)&&h.push(l);if(l instanceof DocumentFragment)for(l=l.firstChild;l;l=l.nextSibling)g.push(l);else g.push(l)}d.apply(this,f);for(f=0;f<h.length;f++)N(a,h[f]);if(K(this))for(f=0;f<g.length;f++)h=g[f],h instanceof Element&&M(a,h)}}var c=Element.prototype;void 0!==Td&&(c.before=b(Td));void 0!==Ud&&(c.after=b(Ud));void 0!==Vd&&
(c.replaceWith=function(d){for(var e=[],f=0;f<arguments.length;++f)e[f]=arguments[f];f=[];for(var g=[],h=0;h<e.length;h++){var k=e[h];k instanceof Element&&K(k)&&g.push(k);if(k instanceof DocumentFragment)for(k=k.firstChild;k;k=k.nextSibling)f.push(k);else f.push(k)}h=K(this);Vd.apply(this,e);for(e=0;e<g.length;e++)N(a,g[e]);if(h)for(N(a,this),e=0;e<f.length;e++)g=f[e],g instanceof Element&&M(a,g)});void 0!==Wd&&(c.remove=function(){var d=K(this);Wd.call(this);d&&N(a,this)})};function ze(a){function b(e,f){Object.defineProperty(e,"innerHTML",{enumerable:f.enumerable,configurable:!0,get:f.get,set:function(g){var h=this,k=void 0;K(this)&&(k=[],he(a,this,function(q){q!==h&&k.push(q)}));f.set.call(this,g);if(k)for(var l=0;l<k.length;l++){var m=k[l];1===m.__CE_state&&a.disconnectedCallback(m)}this.ownerDocument.__CE_registry?O(a,this):ke(a,this);return g}})}function c(e,f){e.insertAdjacentElement=function(g,h){var k=K(h);g=f.call(this,g,h);k&&N(a,h);K(g)&&M(a,h);return g}}
function d(e,f){function g(h,k){for(var l=[];h!==k;h=h.nextSibling)l.push(h);for(k=0;k<l.length;k++)O(a,l[k])}e.insertAdjacentHTML=function(h,k){h=h.toLowerCase();if("beforebegin"===h){var l=this.previousSibling;f.call(this,h,k);g(l||this.parentNode.firstChild,this)}else if("afterbegin"===h)l=this.firstChild,f.call(this,h,k),g(this.firstChild,l);else if("beforeend"===h)l=this.lastChild,f.call(this,h,k),g(l||this.firstChild,null);else if("afterend"===h)l=this.nextSibling,f.call(this,h,k),g(this.nextSibling,
l);else throw new SyntaxError("The value provided ("+String(h)+") is not one of 'beforebegin', 'afterbegin', 'beforeend', or 'afterend'.");}}Hd&&(Element.prototype.attachShadow=function(e){e=Hd.call(this,e);if(a.I&&!e.__CE_patched){e.__CE_patched=!0;for(var f=0;f<a.M.length;f++)a.M[f](e)}return this.__CE_shadowRoot=e});Id&&Id.get?b(Element.prototype,Id):Yd&&Yd.get?b(HTMLElement.prototype,Yd):je(a,function(e){b(e,{enumerable:!0,configurable:!0,get:function(){return Bd.call(this,!0).innerHTML},set:function(f){var g=
"template"===this.localName,h=g?this.content:this,k=vd.call(document,this.namespaceURI,this.localName);for(k.innerHTML=f;0<h.childNodes.length;)Ed.call(h,h.childNodes[0]);for(f=g?k.content:k;0<f.childNodes.length;)Cd.call(h,f.childNodes[0])}})});Element.prototype.setAttribute=function(e,f){if(1!==this.__CE_state)return Kd.call(this,e,f);var g=Jd.call(this,e);Kd.call(this,e,f);f=Jd.call(this,e);a.attributeChangedCallback(this,e,g,f,null)};Element.prototype.setAttributeNS=function(e,f,g){if(1!==this.__CE_state)return Nd.call(this,
e,f,g);var h=Md.call(this,e,f);Nd.call(this,e,f,g);g=Md.call(this,e,f);a.attributeChangedCallback(this,f,h,g,e)};Element.prototype.removeAttribute=function(e){if(1!==this.__CE_state)return Ld.call(this,e);var f=Jd.call(this,e);Ld.call(this,e);null!==f&&a.attributeChangedCallback(this,e,f,null,null)};Element.prototype.removeAttributeNS=function(e,f){if(1!==this.__CE_state)return Od.call(this,e,f);var g=Md.call(this,e,f);Od.call(this,e,f);var h=Md.call(this,e,f);g!==h&&a.attributeChangedCallback(this,
f,g,h,e)};Zd?c(HTMLElement.prototype,Zd):Pd&&c(Element.prototype,Pd);$d?d(HTMLElement.prototype,$d):Qd&&d(Element.prototype,Qd);we(a,Element.prototype,{prepend:Rd,append:Sd});ye(a)};var Ae={};function Be(a){function b(){var c=this.constructor;var d=document.__CE_registry.oa.get(c);if(!d)throw Error("Failed to construct a custom element: The constructor was not registered with `customElements`.");var e=d.constructionStack;if(0===e.length)return e=ud.call(document,d.localName),Object.setPrototypeOf(e,c.prototype),e.__CE_state=1,e.__CE_definition=d,le(a,e),e;var f=e.length-1,g=e[f];if(g===Ae)throw Error("Failed to construct '"+d.localName+"': This element was already constructed.");e[f]=
Ae;Object.setPrototypeOf(g,c.prototype);le(a,g);return g}b.prototype=Xd.prototype;Object.defineProperty(HTMLElement.prototype,"constructor",{writable:!0,configurable:!0,enumerable:!1,value:b});window.HTMLElement=b};function Ce(a){function b(c,d){Object.defineProperty(c,"textContent",{enumerable:d.enumerable,configurable:!0,get:d.get,set:function(e){if(this.nodeType===Node.TEXT_NODE)d.set.call(this,e);else{var f=void 0;if(this.firstChild){var g=this.childNodes,h=g.length;if(0<h&&K(this)){f=Array(h);for(var k=0;k<h;k++)f[k]=g[k]}}d.set.call(this,e);if(f)for(e=0;e<f.length;e++)N(a,f[e])}}})}Node.prototype.insertBefore=function(c,d){if(c instanceof DocumentFragment){var e=de(c);c=Dd.call(this,c,d);if(K(this))for(d=
0;d<e.length;d++)M(a,e[d]);return c}e=c instanceof Element&&K(c);d=Dd.call(this,c,d);e&&N(a,c);K(this)&&M(a,c);return d};Node.prototype.appendChild=function(c){if(c instanceof DocumentFragment){var d=de(c);c=Cd.call(this,c);if(K(this))for(var e=0;e<d.length;e++)M(a,d[e]);return c}d=c instanceof Element&&K(c);e=Cd.call(this,c);d&&N(a,c);K(this)&&M(a,c);return e};Node.prototype.cloneNode=function(c){c=Bd.call(this,!!c);this.ownerDocument.__CE_registry?O(a,c):ke(a,c);return c};Node.prototype.removeChild=
function(c){var d=c instanceof Element&&K(c),e=Ed.call(this,c);d&&N(a,c);return e};Node.prototype.replaceChild=function(c,d){if(c instanceof DocumentFragment){var e=de(c);c=Fd.call(this,c,d);if(K(this))for(N(a,d),d=0;d<e.length;d++)M(a,e[d]);return c}e=c instanceof Element&&K(c);var f=Fd.call(this,c,d),g=K(this);g&&N(a,d);e&&N(a,c);g&&M(a,c);return f};Gd&&Gd.get?b(Node.prototype,Gd):ie(a,function(c){b(c,{enumerable:!0,configurable:!0,get:function(){for(var d=[],e=this.firstChild;e;e=e.nextSibling)e.nodeType!==
Node.COMMENT_NODE&&d.push(e.textContent);return d.join("")},set:function(d){for(;this.firstChild;)Ed.call(this,this.firstChild);null!=d&&""!==d&&Cd.call(this,document.createTextNode(d))}})})};var L=window.customElements;function De(){var a=new ge;Be(a);xe(a);we(a,DocumentFragment.prototype,{prepend:zd,append:Ad});Ce(a);ze(a);window.CustomElementRegistry=P;a=new P(a);document.__CE_registry=a;Object.defineProperty(window,"customElements",{configurable:!0,enumerable:!0,value:a})}L&&!L.forcePolyfill&&"function"==typeof L.define&&"function"==typeof L.get||De();window.__CE_installPolyfill=De;/*

Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
Code distributed by Google as part of the polymer project is also
subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/
function Ee(){this.end=this.start=0;this.rules=this.parent=this.previous=null;this.cssText=this.parsedCssText="";this.atRule=!1;this.type=0;this.parsedSelector=this.selector=this.keyframesName=""}
function Fe(a){var b=a=a.replace(Ge,"").replace(He,""),c=new Ee;c.start=0;c.end=b.length;for(var d=c,e=0,f=b.length;e<f;e++)if("{"===b[e]){d.rules||(d.rules=[]);var g=d,h=g.rules[g.rules.length-1]||null;d=new Ee;d.start=e+1;d.parent=g;d.previous=h;g.rules.push(d)}else"}"===b[e]&&(d.end=e+1,d=d.parent||c);return Ie(c,a)}
function Ie(a,b){var c=b.substring(a.start,a.end-1);a.parsedCssText=a.cssText=c.trim();a.parent&&(c=b.substring(a.previous?a.previous.end:a.parent.start,a.start-1),c=Je(c),c=c.replace(Ke," "),c=c.substring(c.lastIndexOf(";")+1),c=a.parsedSelector=a.selector=c.trim(),a.atRule=0===c.indexOf("@"),a.atRule?0===c.indexOf("@media")?a.type=Le:c.match(Me)&&(a.type=Ne,a.keyframesName=a.selector.split(Ke).pop()):a.type=0===c.indexOf("--")?Oe:Pe);if(c=a.rules)for(var d=0,e=c.length,f=void 0;d<e&&(f=c[d]);d++)Ie(f,
b);return a}function Je(a){return a.replace(/\\([0-9a-f]{1,6})\s/gi,function(b,c){b=c;for(c=6-b.length;c--;)b="0"+b;return"\\"+b})}
function Qe(a,b,c){c=void 0===c?"":c;var d="";if(a.cssText||a.rules){var e=a.rules,f;if(f=e)f=e[0],f=!(f&&f.selector&&0===f.selector.indexOf("--"));if(f){f=0;for(var g=e.length,h=void 0;f<g&&(h=e[f]);f++)d=Qe(h,b,d)}else b?b=a.cssText:(b=a.cssText,b=b.replace(Re,"").replace(Se,""),b=b.replace(Te,"").replace(Ue,"")),(d=b.trim())&&(d="  "+d+"\n")}d&&(a.selector&&(c+=a.selector+" {\n"),c+=d,a.selector&&(c+="}\n\n"));return c}
var Pe=1,Ne=7,Le=4,Oe=1E3,Ge=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//gim,He=/@import[^;]*;/gim,Re=/(?:^[^;\-\s}]+)?--[^;{}]*?:[^{};]*?(?:[;\n]|$)/gim,Se=/(?:^[^;\-\s}]+)?--[^;{}]*?:[^{};]*?{[^}]*?}(?:[;\n]|$)?/gim,Te=/@apply\s*\(?[^);]*\)?\s*(?:[;\n]|$)?/gim,Ue=/[^;:]*?:[^;]*?var\([^;]*\)(?:[;\n]|$)?/gim,Me=/^@[^\s]*keyframes/,Ke=/\s+/g;var Q=!(window.ShadyDOM&&window.ShadyDOM.inUse),Ve;function We(a){Ve=a&&a.shimcssproperties?!1:Q||!(navigator.userAgent.match(/AppleWebKit\/601|Edge\/15/)||!window.CSS||!CSS.supports||!CSS.supports("box-shadow","0 0 0 var(--foo)"))}var Xe;window.ShadyCSS&&void 0!==window.ShadyCSS.cssBuild&&(Xe=window.ShadyCSS.cssBuild);var Ye=!(!window.ShadyCSS||!window.ShadyCSS.disableRuntime);
window.ShadyCSS&&void 0!==window.ShadyCSS.nativeCss?Ve=window.ShadyCSS.nativeCss:window.ShadyCSS?(We(window.ShadyCSS),window.ShadyCSS=void 0):We(window.WebComponents&&window.WebComponents.flags);var R=Ve;var Ze=/(?:^|[;\s{]\s*)(--[\w-]*?)\s*:\s*(?:((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};{])+)|\{([^}]*)\}(?:(?=[;\s}])|$))/gi,$e=/(?:^|\W+)@apply\s*\(?([^);\n]*)\)?/gi,af=/(--[\w-]+)\s*([:,;)]|$)/gi,bf=/(animation\s*:)|(animation-name\s*:)/,cf=/@media\s(.*)/,df=/\{[^}]*\}/g;var ef=new Set;function ff(a,b){if(!a)return"";"string"===typeof a&&(a=Fe(a));b&&gf(a,b);return Qe(a,R)}function hf(a){!a.__cssRules&&a.textContent&&(a.__cssRules=Fe(a.textContent));return a.__cssRules||null}function jf(a){return!!a.parent&&a.parent.type===Ne}function gf(a,b,c,d){if(a){var e=!1,f=a.type;if(d&&f===Le){var g=a.selector.match(cf);g&&(window.matchMedia(g[1]).matches||(e=!0))}f===Pe?b(a):c&&f===Ne?c(a):f===Oe&&(e=!0);if((a=a.rules)&&!e)for(e=0,f=a.length,g=void 0;e<f&&(g=a[e]);e++)gf(g,b,c,d)}}
function kf(a,b,c,d){var e=document.createElement("style");b&&e.setAttribute("scope",b);e.textContent=a;lf(e,c,d);return e}var S=null;function mf(a){a=document.createComment(" Shady DOM styles for "+a+" ");var b=document.head;b.insertBefore(a,(S?S.nextSibling:null)||b.firstChild);return S=a}function lf(a,b,c){b=b||document.head;b.insertBefore(a,c&&c.nextSibling||b.firstChild);S?a.compareDocumentPosition(S)===Node.DOCUMENT_POSITION_PRECEDING&&(S=a):S=a}
function nf(a,b){for(var c=0,d=a.length;b<d;b++)if("("===a[b])c++;else if(")"===a[b]&&0===--c)return b;return-1}function of(a,b){var c=a.indexOf("var(");if(-1===c)return b(a,"","","");var d=nf(a,c+3),e=a.substring(c+4,d);c=a.substring(0,c);a=of(a.substring(d+1),b);d=e.indexOf(",");return-1===d?b(c,e.trim(),"",a):b(c,e.substring(0,d).trim(),e.substring(d+1).trim(),a)}function pf(a,b){Q?a.setAttribute("class",b):window.ShadyDOM.nativeMethods.setAttribute.call(a,"class",b)}
var qf=window.ShadyDOM&&window.ShadyDOM.wrap||function(a){return a};function U(a){var b=a.localName,c="";b?-1<b.indexOf("-")||(c=b,b=a.getAttribute&&a.getAttribute("is")||""):(b=a.is,c=a.extends);return{is:b,T:c}}function rf(a){for(var b=[],c="",d=0;0<=d&&d<a.length;d++)if("("===a[d]){var e=nf(a,d);c+=a.slice(d,e+1);d=e}else","===a[d]?(b.push(c),c=""):c+=a[d];c&&b.push(c);return b}
function sf(a){if(void 0!==Xe)return Xe;if(void 0===a.__cssBuild){var b=a.getAttribute("css-build");if(b)a.__cssBuild=b;else{a:{b="template"===a.localName?a.content.firstChild:a.firstChild;if(b instanceof Comment&&(b=b.textContent.trim().split(":"),"css-build"===b[0])){b=b[1];break a}b=""}if(""!==b){var c="template"===a.localName?a.content.firstChild:a.firstChild;c.parentNode.removeChild(c)}a.__cssBuild=b}}return a.__cssBuild||""}
function tf(a){a=void 0===a?"":a;return""!==a&&R?Q?"shadow"===a:"shady"===a:!1};function uf(){}function vf(a,b){wf(V,a,function(c){W(c,b||"")})}function wf(a,b,c){b.nodeType===Node.ELEMENT_NODE&&c(b);var d;"template"===b.localName?d=(b.content||b._content||b).childNodes:d=b.children||b.childNodes;if(d)for(b=0;b<d.length;b++)wf(a,d[b],c)}
function W(a,b,c){if(b)if(a.classList)c?(a.classList.remove("style-scope"),a.classList.remove(b)):(a.classList.add("style-scope"),a.classList.add(b));else if(a.getAttribute){var d=a.getAttribute("class");c?d&&(b=d.replace("style-scope","").replace(b,""),pf(a,b)):pf(a,(d?d+" ":"")+"style-scope "+b)}}function xf(a,b,c){wf(V,a,function(d){W(d,b,!0);W(d,c)})}function yf(a,b){wf(V,a,function(c){W(c,b||"",!0)})}
function zf(a,b,c,d,e){var f=V;e=void 0===e?"":e;""===e&&(Q||"shady"===(void 0===d?"":d)?e=ff(b,c):(a=U(a),e=Af(f,b,a.is,a.T,c)+"\n\n"));return e.trim()}function Af(a,b,c,d,e){var f=Bf(c,d);c=c?"."+c:"";return ff(b,function(g){g.i||(g.selector=g.m=Cf(a,g,a.h,c,f),g.i=!0);e&&e(g,c,f)})}function Bf(a,b){return b?"[is="+a+"]":a}
function Cf(a,b,c,d,e){var f=rf(b.selector);if(!jf(b)){b=0;for(var g=f.length,h=void 0;b<g&&(h=f[b]);b++)f[b]=c.call(a,h,d,e)}return f.filter(function(k){return!!k}).join(",")}function Df(a){return a.replace(Ef,function(b,c,d){-1<d.indexOf("+")?d=d.replace(/\+/g,"___"):-1<d.indexOf("___")&&(d=d.replace(/___/g,"+"));return":"+c+"("+d+")"})}
function Ff(a){for(var b=[],c;c=a.match(Gf);){var d=c.index,e=nf(a,d);if(-1===e)throw Error(c.input+" selector missing ')'");c=a.slice(d,e+1);a=a.replace(c,"\ue000");b.push(c)}return{na:a,matches:b}}function Hf(a,b){var c=a.split("\ue000");return b.reduce(function(d,e,f){return d+e+c[f+1]},c[0])}
uf.prototype.h=function(a,b,c){var d=!1;a=a.trim();var e=Ef.test(a);e&&(a=a.replace(Ef,function(h,k,l){return":"+k+"("+l.replace(/\s/g,"")+")"}),a=Df(a));var f=Gf.test(a);if(f){var g=Ff(a);a=g.na;g=g.matches}a=a.replace(If,":host $1");a=a.replace(Jf,function(h,k,l){d||(h=Kf(l,k,b,c),d=d||h.stop,k=h.Ga,l=h.value);return k+l});f&&(a=Hf(a,g));e&&(a=Df(a));return a=a.replace(Lf,function(h,k,l,m){return'[dir="'+l+'"] '+k+m+", "+k+'[dir="'+l+'"]'+m})};
function Kf(a,b,c,d){var e=a.indexOf("::slotted");0<=a.indexOf(":host")?a=Mf(a,d):0!==e&&(a=c?Nf(a,c):a);c=!1;0<=e&&(b="",c=!0);if(c){var f=!0;c&&(a=a.replace(Of,function(g,h){return" > "+h}))}return{value:a,Ga:b,stop:f}}function Nf(a,b){a=a.split(/(\[.+?\])/);for(var c=[],d=0;d<a.length;d++)if(1===d%2)c.push(a[d]);else{var e=a[d];if(""!==e||d!==a.length-1)e=e.split(":"),e[0]+=b,c.push(e.join(":"))}return c.join("")}
function Mf(a,b){var c=a.match(Pf);return(c=c&&c[2].trim()||"")?c[0].match(Qf)?a.replace(Pf,function(d,e,f){return b+f}):c.split(Qf)[0]===b?c:"should_not_match":a.replace(":host",b)}function Rf(a){":root"===a.selector&&(a.selector="html")}uf.prototype.i=function(a){return a.match(":host")?"":a.match("::slotted")?this.h(a,":not(.style-scope)"):Nf(a.trim(),":not(.style-scope)")};ca.Object.defineProperties(uf.prototype,{g:{configurable:!0,enumerable:!0,get:function(){return"style-scope"}}});
var Ef=/:(nth[-\w]+)\(([^)]+)\)/,Jf=/(^|[\s>+~]+)((?:\[.+?\]|[^\s>+~=[])+)/g,Qf=/[[.:#*]/,If=/^(::slotted)/,Pf=/(:host)(?:\(((?:\([^)(]*\)|[^)(]*)+?)\))/,Of=/(?:::slotted)(?:\(((?:\([^)(]*\)|[^)(]*)+?)\))/,Lf=/(.*):dir\((?:(ltr|rtl))\)(.*)/,Gf=/:(?:matches|any|-(?:webkit|moz)-any)/,V=new uf;function Sf(a,b,c,d,e){this.A=a||null;this.h=b||null;this.la=c||[];this.u=null;this.cssBuild=e||"";this.T=d||"";this.g=this.v=this.C=null}function X(a){return a?a.__styleInfo:null}function Tf(a,b){return a.__styleInfo=b}Sf.prototype.i=function(){return this.A};Sf.prototype._getStyleRules=Sf.prototype.i;function Uf(a){var b=this.matches||this.matchesSelector||this.mozMatchesSelector||this.msMatchesSelector||this.oMatchesSelector||this.webkitMatchesSelector;return b&&b.call(this,a)}var Vf=/:host\s*>\s*/,Wf=navigator.userAgent.match("Trident");function Xf(){}function Yf(a){var b={},c=[],d=0;gf(a,function(f){Zf(f);f.index=d++;f=f.l.cssText;for(var g;g=af.exec(f);){var h=g[1];":"!==g[2]&&(b[h]=!0)}},function(f){c.push(f)});a.h=c;a=[];for(var e in b)a.push(e);return a}
function Zf(a){if(!a.l){var b={},c={};$f(a,c)&&(b.B=c,a.rules=null);b.cssText=a.parsedCssText.replace(df,"").replace(Ze,"");a.l=b}}function $f(a,b){var c=a.l;if(c){if(c.B)return Object.assign(b,c.B),!0}else{c=a.parsedCssText;for(var d;a=Ze.exec(c);){d=(a[2]||a[3]).trim();if("inherit"!==d||"unset"!==d)b[a[1].trim()]=d;d=!0}return d}}
function ag(a,b,c){b&&(b=0<=b.indexOf(";")?bg(a,b,c):of(b,function(d,e,f,g){if(!e)return d+g;(e=ag(a,c[e],c))&&"initial"!==e?"apply-shim-inherit"===e&&(e="inherit"):e=ag(a,c[f]||f,c)||f;return d+(e||"")+g}));return b&&b.trim()||""}
function bg(a,b,c){b=b.split(";");for(var d=0,e,f;d<b.length;d++)if(e=b[d]){$e.lastIndex=0;if(f=$e.exec(e))e=ag(a,c[f[1]],c);else if(f=e.indexOf(":"),-1!==f){var g=e.substring(f);g=g.trim();g=ag(a,g,c)||g;e=e.substring(0,f)+g}b[d]=e&&e.lastIndexOf(";")===e.length-1?e.slice(0,-1):e||""}return b.join(";")}
function cg(a,b){var c={},d=[];gf(a,function(e){e.l||Zf(e);var f=e.m||e.parsedSelector;b&&e.l.B&&f&&Uf.call(b,f)&&($f(e,c),e=e.index,f=parseInt(e/32,10),d[f]=(d[f]||0)|1<<e%32)},null,!0);return{B:c,key:d}}
function dg(a,b,c,d){b.l||Zf(b);if(b.l.B){var e=U(a);a=e.is;e=e.T;e=a?Bf(a,e):"html";var f=b.parsedSelector;var g=!!f.match(Vf)||"html"===e&&-1<f.indexOf("html");var h=0===f.indexOf(":host")&&!g;"shady"===c&&(g=f===e+" > *."+e||-1!==f.indexOf("html"),h=!g&&0===f.indexOf(e));if(g||h)c=e,h&&(b.m||(b.m=Cf(V,b,V.h,a?"."+a:"",e)),c=b.m||e),g&&"html"===e&&(c=b.m||b.ca),d({na:c,Ma:h,Za:g})}}
function eg(a,b,c){var d={},e={};gf(b,function(f){dg(a,f,c,function(g){Uf.call(a._element||a,g.na)&&(g.Ma?$f(f,d):$f(f,e))})},null,!0);return{Qa:e,La:d}}
function fg(a,b,c,d){var e=U(b),f=Bf(e.is,e.T),g=new RegExp("(?:^|[^.#[:])"+(b.extends?"\\"+f.slice(0,-1)+"\\]":f)+"($|[.:[\\s>+~])"),h=X(b);e=h.A;h=h.cssBuild;var k=gg(e,d);return zf(b,e,function(l){var m="";l.l||Zf(l);l.l.cssText&&(m=bg(a,l.l.cssText,c));l.cssText=m;if(!Q&&!jf(l)&&l.cssText){var q=m=l.cssText;null==l.ua&&(l.ua=bf.test(m));if(l.ua)if(null==l.ba){l.ba=[];for(var v in k)q=k[v],q=q(m),m!==q&&(m=q,l.ba.push(v))}else{for(v=0;v<l.ba.length;++v)q=k[l.ba[v]],m=q(m);q=m}l.cssText=q;l.m=l.m||
l.selector;m="."+d;v=rf(l.m);q=0;for(var T=v.length,cb=void 0;q<T&&(cb=v[q]);q++)v[q]=cb.match(g)?cb.replace(f,m):m+" "+cb;l.selector=v.join(",")}},h)}function gg(a,b){a=a.h;var c={};if(!Q&&a)for(var d=0,e=a[d];d<a.length;e=a[++d]){var f=e,g=b;f.o=new RegExp("\\b"+f.keyframesName+"(?!\\B|-)","g");f.g=f.keyframesName+"-"+g;f.m=f.m||f.selector;f.selector=f.m.replace(f.keyframesName,f.g);c[e.keyframesName]=hg(e)}return c}function hg(a){return function(b){return b.replace(a.o,a.g)}}
function ig(a,b){var c=jg,d=hf(a);a.textContent=ff(d,function(e){var f=e.cssText=e.parsedCssText;e.l&&e.l.cssText&&(f=f.replace(Re,"").replace(Se,""),e.cssText=bg(c,f,b))})}ca.Object.defineProperties(Xf.prototype,{g:{configurable:!0,enumerable:!0,get:function(){return"x-scope"}}});var jg=new Xf;var kg={},lg=window.customElements;if(lg&&!Q&&!Ye){var mg=lg.define;lg.define=function(a,b,c){kg[a]||(kg[a]=mf(a));mg.call(lg,a,b,c)}};function ng(){this.cache={}}ng.prototype.store=function(a,b,c,d){var e=this.cache[a]||[];e.push({B:b,styleElement:c,v:d});100<e.length&&e.shift();this.cache[a]=e};function og(){}var pg=new RegExp(V.g+"\\s*([^\\s]*)");function qg(a){return(a=(a.classList&&a.classList.value?a.classList.value:a.getAttribute("class")||"").match(pg))?a[1]:""}function rg(a){var b=qf(a).getRootNode();return b===a||b===a.ownerDocument?"":(a=b.host)?U(a).is:""}
function sg(a){for(var b=0;b<a.length;b++){var c=a[b];if(c.target!==document.documentElement&&c.target!==document.head)for(var d=0;d<c.addedNodes.length;d++){var e=c.addedNodes[d];if(e.nodeType===Node.ELEMENT_NODE){var f=e.getRootNode(),g=qg(e);if(g&&f===e.ownerDocument&&("style"!==e.localName&&"template"!==e.localName||""===sf(e)))yf(e,g);else if(f instanceof ShadowRoot)for(f=rg(e),f!==g&&xf(e,g,f),e=window.ShadyDOM.nativeMethods.querySelectorAll.call(e,":not(."+V.g+")"),g=0;g<e.length;g++){f=e[g];
var h=rg(f);h&&W(f,h)}}}}}
if(!(Q||window.ShadyDOM&&window.ShadyDOM.handlesDynamicScoping)){var tg=new MutationObserver(sg),ug=function(a){tg.observe(a,{childList:!0,subtree:!0})};if(window.customElements&&!window.customElements.polyfillWrapFlushCallback)ug(document);else{var vg=function(){ug(document.body)};window.HTMLImports?window.HTMLImports.whenReady(vg):requestAnimationFrame(function(){if("loading"===document.readyState){var a=function(){vg();document.removeEventListener("readystatechange",a)};document.addEventListener("readystatechange",
a)}else vg()})}og=function(){sg(tg.takeRecords())}};var wg={};var xg=Promise.resolve();function yg(a){if(a=wg[a])a._applyShimCurrentVersion=a._applyShimCurrentVersion||0,a._applyShimValidatingVersion=a._applyShimValidatingVersion||0,a._applyShimNextVersion=(a._applyShimNextVersion||0)+1}function zg(a){return a._applyShimCurrentVersion===a._applyShimNextVersion}function Ag(a){a._applyShimValidatingVersion=a._applyShimNextVersion;a._validating||(a._validating=!0,xg.then(function(){a._applyShimCurrentVersion=a._applyShimNextVersion;a._validating=!1}))};var Bg={},Cg=new ng;function Y(){this.va={};this.i=document.documentElement;var a=new Ee;a.rules=[];this.o=Tf(this.i,new Sf(a));this.ca=!1;this.g=this.h=null}n=Y.prototype;n.flush=function(){og()};n.Ja=function(a){return hf(a)};n.Ua=function(a){return ff(a)};n.prepareTemplate=function(a,b,c){this.prepareTemplateDom(a,b);this.prepareTemplateStyles(a,b,c)};
n.prepareTemplateStyles=function(a,b,c){if(!a._prepared&&!Ye){Q||kg[b]||(kg[b]=mf(b));a._prepared=!0;a.name=b;a.extends=c;wg[b]=a;var d=sf(a),e=tf(d);c={is:b,extends:c};for(var f=[],g=a.content.querySelectorAll("style"),h=0;h<g.length;h++){var k=g[h];if(k.hasAttribute("shady-unscoped")){if(!Q){var l=k.textContent;if(!ef.has(l)){ef.add(l);var m=document.createElement("style");m.setAttribute("shady-unscoped","");m.textContent=l;document.head.appendChild(m)}k.parentNode.removeChild(k)}}else f.push(k.textContent),
k.parentNode.removeChild(k)}f=f.join("").trim()+(Bg[b]||"");Dg(this);if(!e){if(g=!d)g=$e.test(f)||Ze.test(f),$e.lastIndex=0,Ze.lastIndex=0;h=Fe(f);g&&R&&this.h&&this.h.transformRules(h,b);a._styleAst=h}g=[];R||(g=Yf(a._styleAst));if(!g.length||R)h=Q?a.content:null,b=kg[b]||null,d=zf(c,a._styleAst,null,d,e?f:""),d=d.length?kf(d,c.is,h,b):null,a._style=d;a.g=g}};n.Oa=function(a,b){Bg[b]=a.join(" ")};
n.prepareTemplateDom=function(a,b){if(!Ye){var c=sf(a);Q||"shady"===c||a._domPrepared||(a._domPrepared=!0,vf(a.content,b))}};function Eg(a){var b=U(a),c=b.is;b=b.T;var d=kg[c]||null,e=wg[c];if(e){c=e._styleAst;var f=e.g;e=sf(e);b=new Sf(c,d,f,b,e);Tf(a,b);return b}}
function Fg(a){!a.g&&window.ShadyCSS&&window.ShadyCSS.CustomStyleInterface&&(a.g=window.ShadyCSS.CustomStyleInterface,a.g.transformCallback=function(b){a.ya(b)},a.g.validateCallback=function(){requestAnimationFrame(function(){(a.g.enqueued||a.ca)&&a.flushCustomStyles()})})}function Dg(a){if(!a.h&&window.ShadyCSS&&window.ShadyCSS.ApplyShim){a.h=window.ShadyCSS.ApplyShim;a.h.invalidCallback=yg;var b=!0}else b=!1;Fg(a);return b}
n.flushCustomStyles=function(){if(!Ye){var a=Dg(this);if(this.g){var b=this.g.processStyles();if((a||this.g.enqueued)&&!tf(this.o.cssBuild)){if(R){if(!this.o.cssBuild)for(a=0;a<b.length;a++){var c=this.g.getStyleForCustomStyle(b[a]);if(c&&R&&this.h){var d=hf(c);Dg(this);this.h.transformRules(d);c.textContent=ff(d)}}}else{Gg(this,b);Hg(this,this.i,this.o);for(a=0;a<b.length;a++)(c=this.g.getStyleForCustomStyle(b[a]))&&ig(c,this.o.C);this.ca&&this.styleDocument()}this.g.enqueued=!1}}}};
function Gg(a,b){b=b.map(function(c){return a.g.getStyleForCustomStyle(c)}).filter(function(c){return!!c});b.sort(function(c,d){c=d.compareDocumentPosition(c);return c&Node.DOCUMENT_POSITION_FOLLOWING?1:c&Node.DOCUMENT_POSITION_PRECEDING?-1:0});a.o.A.rules=b.map(function(c){return hf(c)})}
n.styleElement=function(a,b){if(Ye){if(b){X(a)||Tf(a,new Sf(null));var c=X(a);c.u=c.u||{};Object.assign(c.u,b);Ig(this,a,c)}}else if(c=X(a)||Eg(a))if(a!==this.i&&(this.ca=!0),b&&(c.u=c.u||{},Object.assign(c.u,b)),R)Ig(this,a,c);else if(this.flush(),Hg(this,a,c),c.la&&c.la.length){b=U(a).is;var d;a:{if(d=Cg.cache[b])for(var e=d.length-1;0<=e;e--){var f=d[e];b:{var g=c.la;for(var h=0;h<g.length;h++){var k=g[h];if(f.B[k]!==c.C[k]){g=!1;break b}}g=!0}if(g){d=f;break a}}d=void 0}g=d?d.styleElement:null;
e=c.v;(f=d&&d.v)||(f=this.va[b]=(this.va[b]||0)+1,f=b+"-"+f);c.v=f;f=c.v;h=jg;h=g?g.textContent||"":fg(h,a,c.C,f);k=X(a);var l=k.g;l&&!Q&&l!==g&&(l._useCount--,0>=l._useCount&&l.parentNode&&l.parentNode.removeChild(l));Q?k.g?(k.g.textContent=h,g=k.g):h&&(g=kf(h,f,a.shadowRoot,k.h)):g?g.parentNode||(Wf&&-1<h.indexOf("@media")&&(g.textContent=h),lf(g,null,k.h)):h&&(g=kf(h,f,null,k.h));g&&(g._useCount=g._useCount||0,k.g!=g&&g._useCount++,k.g=g);f=g;Q||(g=c.v,k=h=a.getAttribute("class")||"",e&&(k=h.replace(new RegExp("\\s*x-scope\\s*"+
e+"\\s*","g")," ")),k+=(k?" ":"")+"x-scope "+g,h!==k&&pf(a,k));d||Cg.store(b,c.C,f,c.v)}};
function Ig(a,b,c){var d=U(b).is;if(c.u){var e=c.u,f;for(f in e)null===f?b.style.removeProperty(f):b.style.setProperty(f,e[f])}e=wg[d];if(!(!e&&b!==a.i||e&&""!==sf(e))&&e&&e._style&&!zg(e)){if(zg(e)||e._applyShimValidatingVersion!==e._applyShimNextVersion)Dg(a),a.h&&a.h.transformRules(e._styleAst,d),e._style.textContent=zf(b,c.A),Ag(e);Q&&(a=b.shadowRoot)&&(a=a.querySelector("style"))&&(a.textContent=zf(b,c.A));c.A=e._styleAst}}
function Jg(a,b){return(b=qf(b).getRootNode().host)?X(b)||Eg(b)?b:Jg(a,b):a.i}function Hg(a,b,c){var d=Jg(a,b),e=X(d),f=e.C;d===a.i||f||(Hg(a,d,e),f=e.C);a=Object.create(f||null);d=eg(b,c.A,c.cssBuild);b=cg(e.A,b).B;Object.assign(a,d.La,b,d.Qa);b=c.u;for(var g in b)if((e=b[g])||0===e)a[g]=e;g=jg;b=Object.getOwnPropertyNames(a);for(e=0;e<b.length;e++)d=b[e],a[d]=ag(g,a[d],a);c.C=a}n.styleDocument=function(a){this.styleSubtree(this.i,a)};
n.styleSubtree=function(a,b){var c=qf(a),d=c.shadowRoot,e=a===this.i;(d||e)&&this.styleElement(a,b);if(a=e?c:d)for(a=Array.from(a.querySelectorAll("*")).filter(function(f){return qf(f).shadowRoot}),b=0;b<a.length;b++)this.styleSubtree(a[b])};
n.ya=function(a){var b=this,c=sf(a);c!==this.o.cssBuild&&(this.o.cssBuild=c);if(!tf(c)){var d=hf(a);gf(d,function(e){if(Q)Rf(e);else{var f=V;e.selector=e.parsedSelector;Rf(e);e.selector=e.m=Cf(f,e,f.i,void 0,void 0)}R&&""===c&&(Dg(b),b.h&&b.h.transformRule(e))});R?a.textContent=ff(d):this.o.A.rules.push(d)}};n.getComputedStyleValue=function(a,b){var c;R||(c=(X(a)||X(Jg(this,a))).C[b]);return(c=c||window.getComputedStyle(a).getPropertyValue(b))?c.trim():""};
n.Ta=function(a,b){var c=qf(a).getRootNode();b=b?("string"===typeof b?b:String(b)).split(/\s/):[];c=c.host&&c.host.localName;if(!c){var d=a.getAttribute("class");if(d){d=d.split(/\s/);for(var e=0;e<d.length;e++)if(d[e]===V.g){c=d[e+1];break}}}c&&b.push(V.g,c);R||(c=X(a))&&c.v&&b.push(jg.g,c.v);pf(a,b.join(" "))};n.Fa=function(a){return X(a)};n.Sa=function(a,b){W(a,b)};n.Va=function(a,b){W(a,b,!0)};n.Ra=function(a){return rg(a)};n.Ia=function(a){return qg(a)};Y.prototype.flush=Y.prototype.flush;
Y.prototype.prepareTemplate=Y.prototype.prepareTemplate;Y.prototype.styleElement=Y.prototype.styleElement;Y.prototype.styleDocument=Y.prototype.styleDocument;Y.prototype.styleSubtree=Y.prototype.styleSubtree;Y.prototype.getComputedStyleValue=Y.prototype.getComputedStyleValue;Y.prototype.setElementClass=Y.prototype.Ta;Y.prototype._styleInfoForNode=Y.prototype.Fa;Y.prototype.transformCustomStyleForDocument=Y.prototype.ya;Y.prototype.getStyleAst=Y.prototype.Ja;Y.prototype.styleAstToString=Y.prototype.Ua;
Y.prototype.flushCustomStyles=Y.prototype.flushCustomStyles;Y.prototype.scopeNode=Y.prototype.Sa;Y.prototype.unscopeNode=Y.prototype.Va;Y.prototype.scopeForNode=Y.prototype.Ra;Y.prototype.currentScopeForNode=Y.prototype.Ia;Y.prototype.prepareAdoptedCssText=Y.prototype.Oa;Object.defineProperties(Y.prototype,{nativeShadow:{get:function(){return Q}},nativeCss:{get:function(){return R}}});var Z=new Y,Kg,Lg;window.ShadyCSS&&(Kg=window.ShadyCSS.ApplyShim,Lg=window.ShadyCSS.CustomStyleInterface);
window.ShadyCSS={ScopingShim:Z,prepareTemplate:function(a,b,c){Z.flushCustomStyles();Z.prepareTemplate(a,b,c)},prepareTemplateDom:function(a,b){Z.prepareTemplateDom(a,b)},prepareTemplateStyles:function(a,b,c){Z.flushCustomStyles();Z.prepareTemplateStyles(a,b,c)},styleSubtree:function(a,b){Z.flushCustomStyles();Z.styleSubtree(a,b)},styleElement:function(a){Z.flushCustomStyles();Z.styleElement(a)},styleDocument:function(a){Z.flushCustomStyles();Z.styleDocument(a)},flushCustomStyles:function(){Z.flushCustomStyles()},
getComputedStyleValue:function(a,b){return Z.getComputedStyleValue(a,b)},nativeCss:R,nativeShadow:Q,cssBuild:Xe,disableRuntime:Ye};Kg&&(window.ShadyCSS.ApplyShim=Kg);Lg&&(window.ShadyCSS.CustomStyleInterface=Lg);}).call(this);

//# sourceMappingURL=webcomponents-sd-ce.js.map
