import{B as a,d as e,I as t,b as i,i as n,y as s,_ as r,a as d}from"./backend-ai-webui-661d9e43.js";
/**
 @license
Copyright (c) 2015-2023 Lablup Inc. All rights reserved.
*/let o=class extends a{static get styles(){return[e,t,i,n`
      `]}async _viewStateChanged(a){await this.updateComplete}render(){return s`
      <backend-ai-react-information></backend-ai-react-information>
    `}};o=r([d("backend-ai-information-view")],o);var c=o;export{c as default};
